@@ -1,5 +1,8 @@
 new_cg_block <- function(cg_input_object = list(), cg_f_list = list()) {
-  structure(list(cg_input_object = cg_input_object, cg_f_list = cg_f_list), class = "dm_cg_code_block")
+  structure(
+    list(cg_input_object = cg_input_object, cg_f_list = cg_f_list),
+    class = "dm_cg_code_block"
+  )
 }
 
 cg_add_call <- function(cg_block, fn_call) {
