@@ -1,21 +1,24 @@
 #' Copy data model to data source
 #'
 #' @description
-#' `copy_dm_to()` takes a [`dplyr::src_dbi`] object or a [`DBI::DBIConnection-class`] object as its first argument
+#' `copy_dm_to()` takes a [`dbplyr::src_dbi`] object or a [`DBI::DBIConnection-class`] object as its first argument
 #' and a [`dm`] object as its second argument.
 #' The latter is copied to the former.
 #' The default is to create temporary tables, set `temporary = FALSE` to create permanent tables.
-#' Unless `set_key_constraints` is `FALSE`, primary key constraints are set on all databases,
-#' and in addition foreign key constraints are set on MSSQL and Postgres/Redshift databases.
+#' Unless `set_key_constraints` is `FALSE`, primary key, foreign key, and unique constraints
+#' are set, and indexes for foreign keys are created, on all databases.
 #'
 #' @inheritParams dm_examine_constraints
 #'
 #' @param dest An object of class `"src"` or `"DBIConnection"`.
 #' @param dm A `dm` object.
 #' @inheritParams rlang::args_dots_empty
-#' @param set_key_constraints If `TRUE` will mirror `dm` primary and foreign key constraints on a database
-#'   and create indexes for foreign key constraints.
-#'   Set to `FALSE` if your data model currently does not satisfy primary or foreign key constraints.
+#' @param set_key_constraints If `TRUE` will mirror
+#'   the primary, foreign, and unique key constraints
+#'   and create indexes for foreign key constraints
+#'   for the primary and foreign keys in the `dm` object.
+#'   Set to `FALSE` if your data model currently does not satisfy
+#'   primary or foreign key constraints.
 #' @param temporary If `TRUE`, only temporary tables will be created.
 #'   These tables will vanish when disconnecting from the database.
 #' @param schema Name of schema to copy the `dm` to.
@@ -94,144 +97,158 @@ copy_dm_to <- function(
   unique_table_names = NULL,
   copy_to = NULL
 ) {
-  # for the time being, we will be focusing on MSSQL
-  # we want to
-  #   1. change `dm_get_src_impl(dm)` to `dest`
-  #   2. copy the tables to `dest`
-  #   3. implement the key situation within our `dm` on the DB
-
   if (!is.null(unique_table_names)) {
-    deprecate_warn(
-      "0.1.4", "dm::copy_dm_to(unique_table_names = )",
-      details = "Use `table_names = identity` to use unchanged names for temporary tables."
+    deprecate_stop(
+      "0.1.4",
+      "dm::copy_dm_to(unique_table_names = )",
+      details = "Use `table_names = set_names(names(dm))` to use unchanged names for temporary tables."
     )
-
-    if (is.null(table_names) && temporary && !unique_table_names) {
-      table_names <- identity
-    }
   }
 
   if (!is.null(copy_to)) {
     deprecate_stop(
-      "1.0.0", "dm::copy_dm_to(copy_to = )",
+      "1.0.0",
+      "dm::copy_dm_to(copy_to = )",
       details = "Use `dm_sql()` for more control over the schema creation process."
     )
   }
 
   check_dots_empty()
+  dm_local_error_call()
 
   check_not_zoomed(dm)
 
   check_suggested("dbplyr", "copy_dm_to")
 
   dest <- src_from_src_or_con(dest)
-  src_names <- src_tbls_impl(dm)
 
-  if (is_db(dest)) {
-    dest_con <- con_from_src_or_con(dest)
-
-    # in case `table_names` was chosen by the user, check if the input makes sense:
-    # 1. is there one name per dm-table?
-    # 2. are there any duplicated table names?
-    # 3. is it a named character or ident_q vector with the correct names?
-    if (is.null(table_names)) {
-      table_names_out <- repair_table_names_for_db(src_names, temporary, dest_con, schema)
-      # https://github.com/tidyverse/dbplyr/issues/487
-      if (is_mssql(dest)) {
-        temporary <- FALSE
-      }
-    } else {
-      if (!is.null(schema)) abort_one_of_schema_table_names()
-      if (is_function(table_names) || is_bare_formula(table_names)) {
-        table_name_fun <- as_function(table_names)
-        table_names_out <- set_names(table_name_fun(src_names), src_names)
-      } else {
-        table_names_out <- table_names
-      }
-      check_naming(names(table_names_out), src_names)
-
-      if (anyDuplicated(table_names_out)) {
-        problem <- table_names_out[duplicated(table_names_out)][[1]]
-        abort_copy_dm_to_table_names_duplicated(problem)
-      }
-
-      names(table_names_out) <- src_names
-    }
-  } else {
-    # FIXME: Other data sources than local and database possible
-    deprecate_warn(
-      "0.1.6", "dm::copy_dm_to(dest = 'must refer to a remote data source')",
+  if (!is_db(dest)) {
+    deprecate_stop(
+      "0.1.6",
+      "dm::copy_dm_to(dest = 'must refer to a DBI connection')",
       "dm::collect.dm()"
     )
-    table_names_out <- set_names(src_names)
   }
 
-  # FIXME: if same_src(), can use compute() but need to set NOT NULL and other
-  # constraints
+  src_names <- src_tbls_impl(dm)
+  dest_con <- con_from_src_or_con(dest)
 
-  # Shortcut necessary to avoid copying into .GlobalEnv
-  if (!is_db(dest)) {
-    return(dm)
+  # in case `table_names` was chosen by the user, check if the input makes sense:
+  # 1. is there one name per dm-table?
+  # 2. are there any duplicated table names?
+  # 3. is it a named character or ident_q vector with the correct names?
+  if (is.null(table_names)) {
+    table_names_out <- repair_table_names_for_db(src_names, temporary, dest_con, schema)
+    # https://github.com/tidyverse/dbplyr/issues/487
+    if (is_mssql(dest)) {
+      temporary <- FALSE
+    }
+  } else {
+    if (!is.null(schema)) {
+      abort_one_of_schema_table_names()
+    }
+    if (is_function(table_names) || is_bare_formula(table_names)) {
+      table_name_fun <- as_function(table_names)
+      table_names_out <- set_names(table_name_fun(src_names), src_names)
+    } else {
+      table_names_out <- table_names
+    }
+    check_naming(names(table_names_out), src_names)
+
+    if (anyDuplicated(table_names_out)) {
+      problem <- table_names_out[duplicated(table_names_out)][[1]]
+      abort_copy_dm_to_table_names_duplicated(problem)
+    }
+
+    names(table_names_out) <- src_names
   }
 
   # Must be done here because table types may depend on string length, #2066
   dm <- collect(dm, progress = progress)
 
-  queries <- build_copy_queries(dest_con, dm, set_key_constraints, temporary, table_names_out)
+  if (isTRUE(set_key_constraints)) {
+    dm_for_sql <- dm
+  } else {
+    def_no_keys <- dm_get_def(dm)
+    # FIXME: Add test
+    def_no_keys$pks[] <- list(new_pk())
+    def_no_keys$uks[] <- list(new_uk())
+    def_no_keys$fks[] <- list(new_fk())
+    # Must keep primary keys
+    dm_for_sql <- dm_from_def(def_no_keys)
+  }
 
-  ticker_create <- new_ticker(
+  sql <- dm_sql(dm_for_sql, dest_con, table_names_out, temporary)
+
+  # FIXME: Extract function
+  # FIXME: Make descriptions part of the dm_sql() output
+
+  pre <- unlist(sql$pre)
+  load <- unlist(sql$load)
+  post <- unlist(sql$post)
+
+  ticker_pre <- new_ticker(
     "creating tables",
-    n = length(queries$sql_table),
+    n = length(pre),
     progress = progress,
     top_level_fun = "copy_dm_to"
   )
 
   # create tables
-  walk(queries$sql_table, ticker_create(~ {
-    DBI::dbExecute(dest_con, .x, immediate = TRUE)
-  }))
+  walk(
+    pre,
+    ticker_pre(
+      ~ {
+        DBI::dbExecute(dest_con, .x, immediate = TRUE)
+      }
+    )
+  )
 
-  ticker_populate <- new_ticker(
+  ticker_load <- new_ticker(
     "populating tables",
-    n = length(queries$name),
+    n = length(load),
     progress = progress,
     top_level_fun = "copy_dm_to"
   )
 
   # populate tables
-  pwalk(
-    queries[c("name", "remote_name")],
-    ticker_populate(~ db_append_table(
-      con = dest_con,
-      remote_table = .y,
-      table = dm[[.x]],
-      progress = progress,
-      autoinc = dm_get_all_pks(dm, table = !!.x)$autoincrement
-    ))
+  walk(
+    load,
+    ticker_load(
+      ~ {
+        DBI::dbExecute(dest_con, .x, immediate = TRUE)
+      }
+    )
   )
 
-  ticker_index <- new_ticker(
+  ticker_post <- new_ticker(
     "creating indexes",
-    n = sum(lengths(queries$sql_index)),
+    n = length(post),
     progress = progress,
     top_level_fun = "copy_dm_to"
   )
 
   # create indexes
-  walk(unlist(queries$sql_index), ticker_index(~ {
-    DBI::dbExecute(dest_con, .x, immediate = TRUE)
-  }))
+  walk(
+    post,
+    ticker_post(
+      ~ {
+        DBI::dbExecute(dest_con, .x, immediate = TRUE)
+      }
+    )
+  )
 
   # remote dm is same as source dm with replaced data
+  # FIXME: Extract function
   def <- dm_get_def(dm)
 
   remote_tables <- map2(
     table_names_out,
     map(def$data, colnames),
-    ~ tbl(dest_con, ..1, vars = ..2)
+    ~ tbl(dest_con, .x, vars = .y)
   )
 
-  def$data <- unname(remote_tables[names(dm)])
+  def$data <- unname(remote_tables)
   remote_dm <- dm_from_def(def)
 
   invisible(debug_dm_validate(remote_dm))
@@ -243,7 +260,14 @@ check_naming <- function(table_names, dm_table_names) {
   }
 }
 
-db_append_table <- function(con, remote_table, table, progress, top_level_fun = "copy_dm_to", autoinc = logical(0)) {
+db_append_table <- function(
+  con,
+  remote_table,
+  table,
+  progress,
+  top_level_fun = "copy_dm_to",
+  autoinc = logical(0)
+) {
   stopifnot(is.data.frame(table))
   if (nrow(table) == 0 || ncol(table) == 0) {
     return(invisible())
@@ -265,22 +289,34 @@ db_append_table <- function(con, remote_table, table, progress, top_level_fun =
       top_level_fun = top_level_fun
     )
 
-    walk(seq_len(n_chunks), ticker(~ {
-      end <- .x * chunk_size
-      idx <- seq2(end - (chunk_size - 1), min(end, nrow(table)))
-      values <- map(table[idx, , drop = FALSE], mssql_escape, con = con)
-      # Can't use dbAppendTable(): https://github.com/r-dbi/odbc/issues/480
-      sql <- DBI::sqlAppendTable(con, remote_table_id, values, row.names = FALSE)
-      if (length(autoinc) > 1L) abort("more than one autoincrement key in one table")
-      if (!is_empty(autoinc) && autoinc) {
-        sql <- DBI::SQL(paste0(
-          "SET IDENTITY_INSERT ", remote_table_name, " ON\n",
-          sql, "\n",
-          "SET IDENTITY_INSERT ", remote_table_name, " OFF"
-        ))
-      }
-      DBI::dbExecute(con, sql, immediate = TRUE)
-    }))
+    walk(
+      seq_len(n_chunks),
+      ticker(
+        ~ {
+          end <- .x * chunk_size
+          idx <- seq2(end - (chunk_size - 1), min(end, nrow(table)))
+          values <- map(table[idx, , drop = FALSE], mssql_escape, con = con)
+          # Can't use dbAppendTable(): https://github.com/r-dbi/odbc/issues/480
+          sql <- DBI::sqlAppendTable(con, remote_table_id, values, row.names = FALSE)
+          if (length(autoinc) > 1L) {
+            cli::cli_abort("More than one autoincrement key in one table.")
+          }
+          if (!is_empty(autoinc) && autoinc) {
+            sql <- DBI::SQL(paste0(
+              "SET IDENTITY_INSERT ",
+              remote_table_name,
+              " ON\n",
+              sql,
+              "\n",
+              "SET IDENTITY_INSERT ",
+              remote_table_name,
+              " OFF"
+            ))
+          }
+          DBI::dbExecute(con, sql, immediate = TRUE)
+        }
+      )
+    )
   } else if (is_postgres(con) || is_redshift(con)) {
     # https://github.com/r-dbi/RPostgres/issues/384
     table <- as.data.frame(table)
@@ -297,20 +333,20 @@ db_append_table <- function(con, remote_table, table, progress, top_level_fun =
 # Errors ------------------------------------------------------------------
 
 abort_copy_dm_to_table_names <- function() {
-  abort(error_txt_copy_dm_to_table_names(), class = dm_error_full("copy_dm_to_table_names"))
-}
-
-error_txt_copy_dm_to_table_names <- function() {
-  "`table_names` must have names that are the same as the table names in `dm`."
+  cli::cli_abort(
+    "{.arg table_names} must have names that are the same as the table names in {.arg dm}.",
+    class = dm_error_full("copy_dm_to_table_names"),
+    call = dm_error_call()
+  )
 }
 
 abort_copy_dm_to_table_names_duplicated <- function(problem) {
-  abort(error_txt_copy_dm_to_table_names_duplicated(problem), class = dm_error_full("copy_dm_to_table_names_duplicated"))
-}
-
-error_txt_copy_dm_to_table_names_duplicated <- function(problem) {
-  c(
-    "`table_names` must be unique.",
-    i = paste0("Duplicate: ", tick(problem))
+  cli::cli_abort(
+    c(
+      "{.arg table_names} must be unique.",
+      i = "Duplicate: {.code {problem}}"
+    ),
+    class = dm_error_full("copy_dm_to_table_names_duplicated"),
+    call = dm_error_call()
   )
 }
