@@ -28,14 +28,22 @@
 #' dm_nycflights13() %>%
 #'   dm_disambiguate_cols()
 #' @export
-dm_disambiguate_cols <- function(dm, .sep = ".", ..., .quiet = FALSE,
-                                 .position = c("suffix", "prefix")) {
+dm_disambiguate_cols <- function(
+  dm,
+  .sep = ".",
+  ...,
+  .quiet = FALSE,
+  .position = c("suffix", "prefix")
+) {
+  dm_local_error_call()
   check_not_zoomed(dm)
   check_dots_empty()
   .position <- arg_match(.position)
   dm_disambiguate_cols_impl(
     dm,
-    tables = NULL, sep = .sep, quiet = .quiet,
+    tables = NULL,
+    sep = .sep,
+    quiet = .quiet,
     position = .position
   )
 }
@@ -43,7 +51,9 @@ dm_disambiguate_cols <- function(dm, .sep = ".", ..., .quiet = FALSE,
 dm_disambiguate_cols_impl <- function(dm, tables, sep = ".", quiet = FALSE, position = "suffix") {
   table_colnames <- get_table_colnames(dm, tables, exclude_pk = FALSE)
   recipe <- compute_disambiguate_cols_recipe(table_colnames, sep = sep, position = position)
-  if (!quiet) explain_col_rename(recipe)
+  if (!quiet) {
+    explain_col_rename(recipe)
+  }
   col_rename(dm, recipe)
 }
 
@@ -124,16 +134,16 @@ explain_col_rename <- function(recipe) {
   disambiguation <-
     recipe %>%
     unnest(names) %>%
-    mutate(text = glue("dm_rename({tick_if_needed(table)}, {tick_if_needed(new_name)} = {tick_if_needed(column)})")) %>%
+    mutate(
+      text = glue(
+        "dm_rename({tick_if_needed(table)}, {tick_if_needed(new_name)} = {tick_if_needed(column)})"
+      )
+    ) %>%
     pull(text)
 
   message("Renaming ambiguous columns: %>%\n  ", glue_collapse(disambiguation, " %>%\n  "))
 }
 
 col_rename <- function(dm, recipe) {
-  reduce2(recipe$table,
-    recipe$renames,
-    ~ dm_rename(..1, !!..2, !!!..3),
-    .init = dm
-  )
+  reduce2(recipe$table, recipe$renames, ~ dm_rename(..1, !!..2, !!!..3), .init = dm)
 }
