@@ -25,6 +25,8 @@
 #'
 #' nested_dm$airlines
 dm_nest_tbl <- function(dm, child_table, into = NULL) {
+  dm_local_error_call()
+
   # process args
   into <- enquo(into)
   # FIXME: Rename table_name to child_tables_name
@@ -52,27 +54,24 @@ dm_nest_tbl <- function(dm, child_table, into = NULL) {
 
   # make sure we have a terminal child
   if (length(children) || !length(parent_name) || length(parent_name) > 1) {
-    if (length(parent_name)) {
-      parent_msg <- paste0("\nparents: ", toString(paste0("`", parent_name, "`")))
-    } else {
-      parent_msg <- ""
-    }
-    if (length(children)) {
-      children_msg <- paste0("\nchildren: ", toString(paste0("`", children, "`")))
-    } else {
-      children_msg <- ""
-    }
-    abort(glue(
-      "`{table_name}` can't be nested because it is not a terminal child table.",
-      "{parent_msg}{children_msg}"
-    ))
+    cli::cli_abort(
+      c(
+        "{.val {table_name}} can't be nested because it is not a terminal child table.",
+        if (length(parent_name)) "parents: {.val {parent_name}}",
+        if (length(children)) "children: {.val {children}}"
+      ),
+      call = dm_error_call()
+    )
   }
 
   # check consistency of `into` if relevant
   if (!quo_is_null(into)) {
     into <- dm_tbl_name(dm, !!into)
     if (into != parent_name) {
-      abort(glue("`{table_name}` can only be packed into `{child_name}`"))
+      cli::cli_abort(
+        "{.val {table_name}} can only be packed into {.val {child_name}}.",
+        call = dm_error_call()
+      )
     }
   }
 
@@ -80,7 +79,12 @@ dm_nest_tbl <- function(dm, child_table, into = NULL) {
   def <- dm_get_def(dm, quiet = TRUE)
   table_data <- def$data[def$table == table_name][[1]]
   parent_data <- def$data[def$table == parent_name][[1]]
-  nested_data <- nest_join(parent_data, table_data, by = set_names(child_fk, parent_fk), name = table_name)
+  nested_data <- nest_join(
+    parent_data,
+    table_data,
+    by = set_names(child_fk, parent_fk),
+    name = table_name
+  )
   class(nested_data[[table_name]]) <- c("nested", class(nested_data[[table_name]]))
 
   # update def and rebuild dm
@@ -121,6 +125,8 @@ dm_nest_tbl <- function(dm, child_table, into = NULL) {
 #'
 #' dm_packed$flights$planes
 dm_pack_tbl <- function(dm, parent_table, into = NULL) {
+  dm_local_error_call()
+
   # process args
   into <- enquo(into)
   table_name <- dm_tbl_name(dm, {{ parent_table }})
@@ -142,7 +148,10 @@ dm_pack_tbl <- function(dm, parent_table, into = NULL) {
   if (!quo_is_null(into)) {
     into <- dm_tbl_name(dm, !!into)
     if (into != child_name) {
-      abort(glue("`{table_name}` can only be packed into `{child_name}`"))
+      cli::cli_abort(
+        "{.val {table_name}} can only be packed into {.val {child_name}}.",
+        call = dm_error_call()
+      )
     }
   }
 
@@ -150,7 +159,12 @@ dm_pack_tbl <- function(dm, parent_table, into = NULL) {
   def <- dm_get_def(dm, quiet = TRUE)
   table_data <- def$data[def$table == table_name][[1]]
   child_data <- def$data[def$table == child_name][[1]]
-  packed_data <- pack_join(child_data, table_data, by = set_names(parent_fk, child_fk), name = table_name)
+  packed_data <- pack_join(
+    child_data,
+    table_data,
+    by = set_names(parent_fk, child_fk),
+    name = table_name
+  )
   class(packed_data[[table_name]]) <- c("packed", class(packed_data[[table_name]]))
 
   # update def and rebuild dm
@@ -171,30 +185,23 @@ check_table_can_be_packed <- function(table_name, children_names, fks) {
   table_has_one_child <- length(children_names) == 1
   table_is_terminal_parent <- table_has_one_child && !table_has_parents
   if (!table_is_terminal_parent) {
-    if (table_has_parents) {
-      parent_msg <- paste0("\nparents : ", toString(paste0("`", parents, "`")))
-    } else {
-      parent_msg <- ""
-    }
-    table_has_children <- length(children_names) > 0
-    if (table_has_children) {
-      children_msg <- paste0("\nchildren: ", toString(paste0("`", children_names, "`")))
-    } else {
-      children_msg <- ""
-    }
-    abort(glue(
-      "`{table_name}` can't be packed because it is not a terminal parent table.",
-      "{parent_msg}{children_msg}"
-    ))
+    cli::cli_abort(
+      c(
+        "{.val {table_name}} can't be packed because it is not a terminal parent table.",
+        if (length(parents) > 0) "parents : {.val {parents}}",
+        if (length(children_names) > 0) "children: {.val {children_names}}"
+      ),
+      call = dm_error_call()
+    )
   }
   invisible(NULL)
 }
 
 # FIXME: can we be more efficient ?
 node_type_from_graph <- function(graph, drop = NULL) {
-  vertices <- igraph::V(graph)
-  n_children <- map_dbl(vertices, ~ length(igraph::neighbors(graph, .x, mode = "in")))
-  n_parents <- map_dbl(vertices, ~ length(igraph::neighbors(graph, .x, mode = "out")))
+  vertices <- graph_vertices(graph)
+  n_children <- map_dbl(vertices, ~ length(graph_neighbors(graph, .x, mode = "in")))
+  n_parents <- map_dbl(vertices, ~ length(graph_neighbors(graph, .x, mode = "out")))
   node_types <- set_names(rep_along(vertices, "intermediate"), names(vertices))
   node_types[n_parents == 0 & n_children == 1] <- "terminal parent"
   node_types[n_children == 0 & n_parents == 1] <- "terminal child"
