@@ -4,45 +4,125 @@
 #' Use these methods without the '.dm_zoomed' suffix (see examples).
 #' @param .data object of class `dm_zoomed`
 #' @param ... see corresponding function in package \pkg{dplyr} or \pkg{tidyr}
+#' @inheritParams dplyr::filter
+#' @inheritParams dplyr::arrange
+#' @inheritParams dplyr::group_by
+#' @inheritParams dplyr::summarise
+#' @inheritParams dplyr::mutate
 #' @name dplyr_table_manipulation
 #' @examplesIf rlang::is_installed("nycflights13")
 #' zoomed <- dm_nycflights13() %>%
 #'   dm_zoom_to(flights) %>%
-#'   group_by(month) %>%
 #'   arrange(desc(day)) %>%
-#'   summarize(avg_air_time = mean(air_time, na.rm = TRUE))
+#'   summarize(.by = month, avg_air_time = mean(air_time, na.rm = TRUE))
 #' zoomed
 #' dm_insert_zoomed(zoomed, new_tbl_name = "avg_air_time_per_month")
 NULL
 
 #' @export
-filter.dm <- function(.data, ...) {
+filter.dm <- function(.data, ..., .by = NULL, .preserve = FALSE) {
   check_zoomed(.data)
 }
 
 #' @rdname dplyr_table_manipulation
 #' @export
-filter.dm_zoomed <- function(.data, ...) {
-  .data %>%
-    dm_filter_impl(..., set_filter = FALSE)
-}
-
-#' @export
-mutate.dm <- function(.data, ...) {
-  check_zoomed(.data)
-}
-
-#' @rdname dplyr_table_manipulation
-#' @export
-mutate.dm_zoomed <- function(.data, ...) {
+filter.dm_zoomed <- function(.data, ..., .by = NULL, .preserve = FALSE) {
   tbl <- tbl_zoomed(.data)
-  mutated_tbl <- mutate(tbl, ...)
+  filtered_tbl <- filter(tbl, ..., .by = {{ .by }}, .preserve = .preserve)
+  replace_zoomed_tbl(.data, filtered_tbl)
+}
+
+#' @rdname dplyr_table_manipulation
+#' @export
+filter.dm_keyed_tbl <- function(.data, ..., .by = NULL, .preserve = FALSE) {
+  keys_info <- keyed_get_info(.data)
+  tbl <- unclass_keyed_tbl(.data)
+  filtered_tbl <- filter(tbl, ..., .by = {{ .by }}, .preserve = .preserve)
+  new_keyed_tbl_from_keys_info(filtered_tbl, keys_info)
+}
+
+#' @export
+filter_out.dm <- function(.data, ..., .by = NULL, .preserve = FALSE) {
+  check_zoomed(.data)
+}
+
+#' @rdname dplyr_table_manipulation
+#' @export
+filter_out.dm_zoomed <- function(.data, ..., .by = NULL, .preserve = FALSE) {
+  tbl <- tbl_zoomed(.data)
+  filtered_tbl <- filter_out(tbl, ..., .by = {{ .by }}, .preserve = .preserve)
+  replace_zoomed_tbl(.data, filtered_tbl)
+}
+
+#' @rdname dplyr_table_manipulation
+#' @export
+filter_out.dm_keyed_tbl <- function(.data, ..., .by = NULL, .preserve = FALSE) {
+  keys_info <- keyed_get_info(.data)
+  tbl <- unclass_keyed_tbl(.data)
+  filtered_tbl <- filter_out(tbl, ..., .by = {{ .by }}, .preserve = .preserve)
+  new_keyed_tbl_from_keys_info(filtered_tbl, keys_info)
+}
+
+#' @export
+mutate.dm <- function(
+  .data,
+  ...,
+  .by = NULL,
+  .keep = c("all", "used", "unused", "none"),
+  .before = NULL,
+  .after = NULL
+) {
+  check_zoomed(.data)
+}
+
+#' @rdname dplyr_table_manipulation
+#' @export
+mutate.dm_zoomed <- function(
+  .data,
+  ...,
+  .by = NULL,
+  .keep = c("all", "used", "unused", "none"),
+  .before = NULL,
+  .after = NULL
+) {
+  tbl <- tbl_zoomed(.data)
+  mutated_tbl <- mutate(
+    tbl,
+    ...,
+    .by = {{ .by }},
+    .keep = .keep,
+    .before = {{ .before }},
+    .after = {{ .after }}
+  )
   # #663: user responsibility: those columns are tracked whose names remain
   selected <- set_names(intersect(colnames(tbl), colnames(mutated_tbl)))
   new_tracked_cols_zoom <- new_tracked_cols(.data, selected)
   replace_zoomed_tbl(.data, mutated_tbl, new_tracked_cols_zoom)
 }
 
+#' @rdname dplyr_table_manipulation
+#' @export
+mutate.dm_keyed_tbl <- function(
+  .data,
+  ...,
+  .by = NULL,
+  .keep = c("all", "used", "unused", "none"),
+  .before = NULL,
+  .after = NULL
+) {
+  keys_info <- keyed_get_info(.data)
+  tbl <- unclass_keyed_tbl(.data)
+  out <- mutate(
+    tbl,
+    ...,
+    .by = {{ .by }},
+    .keep = .keep,
+    .before = {{ .before }},
+    .after = {{ .after }}
+  )
+  new_keyed_tbl_from_keys_info(out, keys_info)
+}
+
 #' @export
 transmute.dm <- function(.data, ...) {
   check_zoomed(.data)
@@ -63,6 +143,15 @@ transmute.dm_zoomed <- function(.data, ...) {
   replace_zoomed_tbl(.data, transmuted_tbl, new_tracked_cols_zoom)
 }
 
+#' @rdname dplyr_table_manipulation
+#' @export
+transmute.dm_keyed_tbl <- function(.data, ...) {
+  keys_info <- keyed_get_info(.data)
+  tbl <- unclass_keyed_tbl(.data)
+  out <- transmute(tbl, ...)
+  new_keyed_tbl_from_keys_info(out, keys_info)
+}
+
 #' @export
 select.dm <- function(.data, ...) {
   check_zoomed(.data)
@@ -80,8 +169,17 @@ select.dm_zoomed <- function(.data, ...) {
   replace_zoomed_tbl(.data, selected_tbl, new_tracked_cols_zoom)
 }
 
+#' @rdname dplyr_table_manipulation
 #' @export
-relocate.dm <- function(.data, ...) {
+select.dm_keyed_tbl <- function(.data, ...) {
+  keys_info <- keyed_get_info(.data)
+  tbl <- unclass_keyed_tbl(.data)
+  out <- select(tbl, ...)
+  new_keyed_tbl_from_keys_info(out, keys_info)
+}
+
+#' @export
+relocate.dm <- function(.data, ..., .before = NULL, .after = NULL) {
   check_zoomed(.data)
 }
 
@@ -95,6 +193,15 @@ relocate.dm_zoomed <- function(.data, ..., .before = NULL, .after = NULL) {
   replace_zoomed_tbl(.data, relocated_tbl)
 }
 
+#' @rdname dplyr_table_manipulation
+#' @export
+relocate.dm_keyed_tbl <- function(.data, ..., .before = NULL, .after = NULL) {
+  keys_info <- keyed_get_info(.data)
+  tbl <- unclass_keyed_tbl(.data)
+  relocated_tbl <- relocate(tbl, ..., .before = {{ .before }}, .after = {{ .after }})
+  new_keyed_tbl_from_keys_info(relocated_tbl, keys_info)
+}
+
 #' @export
 rename.dm <- function(.data, ...) {
   check_zoomed(.data)
@@ -112,8 +219,17 @@ rename.dm_zoomed <- function(.data, ...) {
   replace_zoomed_tbl(.data, renamed_tbl, new_tracked_cols_zoom)
 }
 
+#' @rdname dplyr_table_manipulation
 #' @export
-distinct.dm <- function(.data, ...) {
+rename.dm_keyed_tbl <- function(.data, ...) {
+  keys_info <- keyed_get_info(.data)
+  tbl <- unclass_keyed_tbl(.data)
+  out <- rename(tbl, ...)
+  new_keyed_tbl_from_keys_info(out, keys_info)
+}
+
+#' @export
+distinct.dm <- function(.data, ..., .keep_all = FALSE) {
   check_zoomed(.data)
 }
 
@@ -131,21 +247,39 @@ distinct.dm_zoomed <- function(.data, ..., .keep_all = FALSE) {
   replace_zoomed_tbl(.data, distinct_tbl, new_tracked_cols_zoom)
 }
 
+#' @rdname dplyr_table_manipulation
 #' @export
-arrange.dm <- function(.data, ...) {
+distinct.dm_keyed_tbl <- function(.data, ..., .keep_all = FALSE) {
+  keys_info <- keyed_get_info(.data)
+  tbl <- unclass_keyed_tbl(.data)
+  distinct_tbl <- distinct(tbl, ..., .keep_all = .keep_all)
+  new_keyed_tbl_from_keys_info(distinct_tbl, keys_info)
+}
+
+#' @export
+arrange.dm <- function(.data, ..., .by_group = FALSE, .locale = NULL) {
   check_zoomed(.data)
 }
 
 #' @rdname dplyr_table_manipulation
 #' @export
-arrange.dm_zoomed <- function(.data, ...) {
+arrange.dm_zoomed <- function(.data, ..., .by_group = FALSE, .locale = NULL) {
   tbl <- tbl_zoomed(.data)
-  arranged_tbl <- arrange(tbl, ...)
+  arranged_tbl <- arrange(tbl, ..., .by_group = .by_group, .locale = .locale)
   replace_zoomed_tbl(.data, arranged_tbl)
 }
 
+#' @rdname dplyr_table_manipulation
 #' @export
-slice.dm <- function(.data, ...) {
+arrange.dm_keyed_tbl <- function(.data, ..., .by_group = FALSE, .locale = NULL) {
+  keys_info <- keyed_get_info(.data)
+  tbl <- unclass_keyed_tbl(.data)
+  arranged_tbl <- arrange(tbl, ..., .by_group = .by_group, .locale = .locale)
+  new_keyed_tbl_from_keys_info(arranged_tbl, keys_info)
+}
+
+#' @export
+slice.dm <- function(.data, ..., .by = NULL, .preserve = FALSE) {
   check_zoomed(.data)
 }
 
@@ -154,8 +288,8 @@ slice.dm <- function(.data, ...) {
 #' By default, the value is `NULL`, which causes the function to issue a message in case a primary key is available for the zoomed table.
 #' This argument is specific for the `slice.dm_zoomed()` method.
 #' @export
-slice.dm_zoomed <- function(.data, ..., .keep_pk = NULL) {
-  sliced_tbl <- slice(tbl_zoomed(.data), ...)
+slice.dm_zoomed <- function(.data, ..., .by = NULL, .preserve = FALSE, .keep_pk = NULL) {
+  sliced_tbl <- slice(tbl_zoomed(.data), ..., .by = {{ .by }}, .preserve = .preserve)
   orig_pk <- dm_get_pk_impl(.data, orig_name_zoomed(.data))
   tracked_cols <- col_tracker_zoomed(.data)
   if (is_null(.keep_pk)) {
@@ -173,26 +307,35 @@ slice.dm_zoomed <- function(.data, ..., .keep_pk = NULL) {
   replace_zoomed_tbl(.data, sliced_tbl, tracked_cols)
 }
 
+#' @rdname dplyr_table_manipulation
 #' @export
-group_by.dm <- function(.data, ...) {
+slice.dm_keyed_tbl <- function(.data, ..., .by = NULL, .preserve = FALSE) {
+  keys_info <- keyed_get_info(.data)
+  tbl <- unclass_keyed_tbl(.data)
+  sliced_tbl <- slice(tbl, ..., .by = {{ .by }}, .preserve = .preserve)
+  new_keyed_tbl_from_keys_info(sliced_tbl, keys_info)
+}
+
+#' @export
+group_by.dm <- function(.data, ..., .add = FALSE, .drop = group_by_drop_default(.data)) {
   check_zoomed(.data)
 }
 
 #' @rdname dplyr_table_manipulation
 #' @export
-group_by.dm_zoomed <- function(.data, ...) {
+group_by.dm_zoomed <- function(.data, ..., .add = FALSE, .drop = group_by_drop_default(.data)) {
   tbl <- tbl_zoomed(.data)
-  grouped_tbl <- group_by(tbl, ...)
+  grouped_tbl <- group_by(tbl, ..., .add = .add, .drop = .drop)
 
   replace_zoomed_tbl(.data, grouped_tbl)
 }
 
 #' @rdname dplyr_table_manipulation
 #' @export
-group_by.dm_keyed_tbl <- function(.data, ...) {
+group_by.dm_keyed_tbl <- function(.data, ..., .add = FALSE, .drop = group_by_drop_default(.data)) {
   keys_info <- keyed_get_info(.data)
   tbl <- unclass_keyed_tbl(.data)
-  grouped_tbl <- group_by(tbl, ...)
+  grouped_tbl <- group_by(tbl, ..., .add = .add, .drop = .drop)
   new_keyed_tbl_from_keys_info(grouped_tbl, keys_info)
 }
 
@@ -269,19 +412,34 @@ ungroup.dm_zoomed <- function(x, ...) {
   replace_zoomed_tbl(x, ungrouped_tbl)
 }
 
+#' @rdname dplyr_table_manipulation
 #' @export
-summarise.dm <- function(.data, ...) {
+ungroup.dm_keyed_tbl <- function(x, ...) {
+  keys_info <- keyed_get_info(x)
+  tbl <- unclass_keyed_tbl(x)
+  ungrouped_tbl <- ungroup(tbl, ...)
+  new_keyed_tbl_from_keys_info(ungrouped_tbl, keys_info)
+}
+
+#' @export
+summarise.dm <- function(.data, ..., .by = NULL, .groups = NULL) {
   check_zoomed(.data)
 }
 
 #' @rdname dplyr_table_manipulation
 #' @export
-summarise.dm_zoomed <- function(.data, ...) {
+summarise.dm_zoomed <- function(.data, ..., .by = NULL, .groups = NULL) {
   tbl <- tbl_zoomed(.data)
-  # groups are "selected"; key tracking will continue for them
-  # #663: user responsibility: if group columns are manipulated, they are still tracked
-  groups <- set_names(map_chr(groups(tbl), as_string))
-  summarized_tbl <- summarize(tbl, ...)
+  by <- enquo(.by)
+  if (!quo_is_null(by)) {
+    by_loc <- tidyselect::eval_select(by, data = tbl)
+    groups <- set_names(names(by_loc))
+  } else {
+    # groups are "selected"; key tracking will continue for them
+    # #663: user responsibility: if group columns are manipulated, they are still tracked
+    groups <- set_names(map_chr(groups(tbl), as_string))
+  }
+  summarized_tbl <- summarize(tbl, ..., .by = !!by, .groups = .groups)
   new_tracked_cols_zoom <- new_tracked_cols(.data, groups)
   replace_zoomed_tbl(.data, summarized_tbl, new_tracked_cols_zoom)
 }
@@ -289,36 +447,91 @@ summarise.dm_zoomed <- function(.data, ...) {
 
 #' @rdname dplyr_table_manipulation
 #' @export
-summarise.dm_keyed_tbl <- function(.data, ...) {
+summarise.dm_keyed_tbl <- function(.data, ..., .by = NULL, .groups = NULL) {
   keys_info <- keyed_get_info(.data)
   tbl <- unclass_keyed_tbl(.data)
 
-  new_pk <- group_vars(.data)
+  by <- enquo(.by)
+  if (!quo_is_null(by)) {
+    by_loc <- tidyselect::eval_select(by, data = tbl)
+    new_pk <- names(by_loc)
+  } else {
+    new_pk <- group_vars(.data)
+  }
   if (length(new_pk) == 0) {
     new_pk <- NULL
   }
 
-  summarised_tbl <- NextMethod()
+  summarised_tbl <- summarise(tbl, ..., .by = !!by, .groups = .groups)
 
   # FIXME: Add original FKs for the remaining columns
   # (subsets of the grouped columns), use new UUID
   new_keyed_tbl(
     summarised_tbl,
     pk = new_pk,
-    uuid = keys_info$uuid
+    uuid = keys_info$uuid,
+    zoom2 = keys_info$zoom2
   )
 }
 
 #' @export
-count.dm <- function(x, ...) {
+reframe.dm <- function(.data, ..., .by = NULL) {
+  check_zoomed(.data)
+}
+
+#' @rdname dplyr_table_manipulation
+#' @export
+reframe.dm_zoomed <- function(.data, ..., .by = NULL) {
+  tbl <- tbl_zoomed(.data)
+  reframed_tbl <- reframe(tbl, ..., .by = {{ .by }})
+  # reframe() always returns ungrouped data, no group tracking needed
+  # #663: user responsibility: those columns are tracked whose names remain
+  selected <- set_names(intersect(colnames(tbl_zoomed(.data)), colnames(reframed_tbl)))
+  new_tracked_cols_zoom <- new_tracked_cols(.data, selected)
+  replace_zoomed_tbl(.data, reframed_tbl, new_tracked_cols_zoom)
+}
+
+#' @rdname dplyr_table_manipulation
+#' @export
+reframe.dm_keyed_tbl <- function(.data, ..., .by = NULL) {
+  keys_info <- keyed_get_info(.data)
+  tbl <- unclass_keyed_tbl(.data)
+
+  reframed_tbl <- reframe(tbl, ..., .by = {{ .by }})
+
+  # reframe() can return any number of rows per group,
+
+  # so the primary key is not preserved
+  new_keyed_tbl(
+    reframed_tbl,
+    uuid = keys_info$uuid,
+    zoom2 = keys_info$zoom2
+  )
+}
+
+#' @export
+count.dm <- function(
+  x,
+  ...,
+  wt = NULL,
+  sort = FALSE,
+  name = NULL,
+  .drop = group_by_drop_default(x)
+) {
   check_zoomed(x)
 }
 
 #' @rdname dplyr_table_manipulation
 #' @inheritParams dplyr::count
 #' @export
-count.dm_zoomed <- function(x, ..., wt = NULL, sort = FALSE, name = NULL,
-                            .drop = group_by_drop_default(x)) {
+count.dm_zoomed <- function(
+  x,
+  ...,
+  wt = NULL,
+  sort = FALSE,
+  name = NULL,
+  .drop = group_by_drop_default(x)
+) {
   tbl <- tbl_zoomed(x)
 
   if (!missing(...)) {
@@ -340,18 +553,38 @@ count.dm_zoomed <- function(x, ..., wt = NULL, sort = FALSE, name = NULL,
   replace_zoomed_tbl(x, out, new_tracked_cols_zoom)
 }
 
+#' @rdname dplyr_table_manipulation
 #' @export
-tally.dm <- function(x, ...) {
+count.dm_keyed_tbl <- function(
+  x,
+  ...,
+  wt = NULL,
+  sort = FALSE,
+  name = NULL,
+  .drop = group_by_drop_default(x)
+) {
+  keys_info <- keyed_get_info(x)
+  tbl <- unclass_keyed_tbl(x)
+  counted_tbl <- count(tbl, ..., wt = {{ wt }}, sort = sort, name = name, .drop = .drop)
+  new_keyed_tbl(
+    counted_tbl,
+    uuid = keys_info$uuid,
+    zoom2 = keys_info$zoom2
+  )
+}
+
+#' @export
+tally.dm <- function(x, wt = NULL, sort = FALSE, name = NULL) {
   check_zoomed(x)
 }
 
 #' @rdname dplyr_table_manipulation
 #' @export
-tally.dm_zoomed <- function(x, ...) {
+tally.dm_zoomed <- function(x, wt = NULL, sort = FALSE, name = NULL) {
   tbl <- tbl_zoomed(x)
   groups <- set_names(map_chr(groups(tbl), as_string))
 
-  out <- tally(tbl, ...)
+  out <- tally(tbl, wt = {{ wt }}, sort = sort, name = name)
 
   # Ensure grouping is transient
   if (is.data.frame(tbl)) {
@@ -362,6 +595,19 @@ tally.dm_zoomed <- function(x, ...) {
   replace_zoomed_tbl(x, out, new_tracked_cols_zoom)
 }
 
+#' @rdname dplyr_table_manipulation
+#' @export
+tally.dm_keyed_tbl <- function(x, wt = NULL, sort = FALSE, name = NULL) {
+  keys_info <- keyed_get_info(x)
+  tbl <- unclass_keyed_tbl(x)
+  tallied_tbl <- tally(tbl, wt = {{ wt }}, sort = sort, name = name)
+  new_keyed_tbl(
+    tallied_tbl,
+    uuid = keys_info$uuid,
+    zoom2 = keys_info$zoom2
+  )
+}
+
 #' @export
 pull.dm <- function(.data, var = -1, name = NULL, ...) {
   check_zoomed(.data)
@@ -370,9 +616,9 @@ pull.dm <- function(.data, var = -1, name = NULL, ...) {
 #' @rdname dplyr_table_manipulation
 #' @inheritParams dplyr::pull
 #' @export
-pull.dm_zoomed <- function(.data, var = -1, ...) {
+pull.dm_zoomed <- function(.data, var = -1, name = NULL, ...) {
   tbl <- tbl_zoomed(.data)
-  pull(tbl, var = {{ var }}, ...)
+  pull(tbl, var = {{ var }}, name = {{ name }}, ...)
 }
 
 #' @rdname dplyr_table_manipulation
@@ -398,6 +644,7 @@ compute.dm_zoomed <- function(x, ...) {
 #' This argument is specific for the `join`-methods for `dm_zoomed`.
 #' The table's `by` column(s) are automatically added if missing in the selection.
 #' @param ... see [`dplyr::join`]
+#' @inheritParams dplyr::left_join
 #' @examplesIf rlang::is_installed("nycflights13")
 #' flights_dm <- dm_nycflights13()
 #' dm_zoom_to(flights_dm, flights) %>%
@@ -409,32 +656,86 @@ compute.dm_zoomed <- function(x, ...) {
 NULL
 
 #' @export
-left_join.dm <- function(x, ...) {
+left_join.dm <- function(
+  x,
+  y,
+  by = NULL,
+  copy = FALSE,
+  suffix = c(".x", ".y"),
+  ...,
+  keep = NULL,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  unmatched = "drop",
+  relationship = NULL
+) {
   check_zoomed(x)
 }
 
 #' @rdname dplyr_join
 #' @export
-left_join.dm_zoomed <- function(x, y, by = NULL, copy = NULL, suffix = NULL, select = NULL, ...) {
+left_join.dm_zoomed <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  suffix = NULL,
+  ...,
+  keep = NULL,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  unmatched = "drop",
+  relationship = NULL,
+  select = NULL
+) {
   y_name <- as_string(enexpr(y))
   join_data <- prepare_join(x, {{ y }}, by, {{ select }}, suffix, copy)
-  joined_tbl <- left_join(join_data$x_tbl, join_data$y_tbl, join_data$by, copy = FALSE, ...)
+  joined_tbl <- left_join(
+    join_data$x_tbl,
+    join_data$y_tbl,
+    join_data$by,
+    copy = FALSE,
+    ...,
+    keep = keep,
+    na_matches = na_matches,
+    multiple = multiple,
+    unmatched = unmatched,
+    relationship = relationship
+  )
   replace_zoomed_tbl(x, joined_tbl, join_data$new_col_names)
 }
 
 #' @rdname dplyr_join
 #' @export
-left_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, suffix = NULL, ..., keep = FALSE) {
+left_join.dm_keyed_tbl <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  suffix = NULL,
+  ...,
+  keep = FALSE,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  unmatched = "drop",
+  relationship = NULL
+) {
   if (!is_dm_keyed_tbl(y)) {
     return(NextMethod())
   }
 
   join_spec <- keyed_build_join_spec(x, y, by, suffix)
   joined_tbl <- left_join(
-    join_spec$x_tbl, join_spec$y_tbl, deframe(join_spec$by),
+    join_spec$x_tbl,
+    join_spec$y_tbl,
+    deframe(join_spec$by),
     copy = copy,
     suffix = join_spec$suffix,
     keep = keep,
+    na_matches = na_matches,
+    multiple = multiple,
+    unmatched = unmatched,
+    relationship = relationship,
     ...
   )
 
@@ -443,37 +744,92 @@ left_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, suffix = NULL,
     pk = join_spec$new_pk,
     fks_in = join_spec$new_fks_in,
     fks_out = join_spec$new_fks_out,
-    uuid = join_spec$new_uuid
+    uuid = join_spec$new_uuid,
+    zoom2 = keyed_get_info(x)$zoom2
   )
 }
 
 #' @export
-inner_join.dm <- function(x, ...) {
+inner_join.dm <- function(
+  x,
+  y,
+  by = NULL,
+  copy = FALSE,
+  suffix = c(".x", ".y"),
+  ...,
+  keep = NULL,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  unmatched = "drop",
+  relationship = NULL
+) {
   check_zoomed(x)
 }
 
 #' @rdname dplyr_join
 #' @export
-inner_join.dm_zoomed <- function(x, y, by = NULL, copy = NULL, suffix = NULL, select = NULL, ...) {
+inner_join.dm_zoomed <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  suffix = NULL,
+  ...,
+  keep = NULL,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  unmatched = "drop",
+  relationship = NULL,
+  select = NULL
+) {
   y_name <- as_string(enexpr(y))
   join_data <- prepare_join(x, {{ y }}, by, {{ select }}, suffix, copy)
-  joined_tbl <- inner_join(join_data$x_tbl, join_data$y_tbl, join_data$by, copy = FALSE, ...)
+  joined_tbl <- inner_join(
+    join_data$x_tbl,
+    join_data$y_tbl,
+    join_data$by,
+    copy = FALSE,
+    ...,
+    keep = keep,
+    na_matches = na_matches,
+    multiple = multiple,
+    unmatched = unmatched,
+    relationship = relationship
+  )
   replace_zoomed_tbl(x, joined_tbl, join_data$new_col_names)
 }
 
 #' @rdname dplyr_join
 #' @export
-inner_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, suffix = NULL, ..., keep = FALSE) {
+inner_join.dm_keyed_tbl <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  suffix = NULL,
+  ...,
+  keep = FALSE,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  unmatched = "drop",
+  relationship = NULL
+) {
   if (!is_dm_keyed_tbl(y)) {
     return(NextMethod())
   }
 
   join_spec <- keyed_build_join_spec(x, y, by, suffix)
   joined_tbl <- inner_join(
-    join_spec$x_tbl, join_spec$y_tbl, deframe(join_spec$by),
+    join_spec$x_tbl,
+    join_spec$y_tbl,
+    deframe(join_spec$by),
     copy = copy,
     suffix = join_spec$suffix,
     keep = keep,
+    na_matches = na_matches,
+    multiple = multiple,
+    unmatched = unmatched,
+    relationship = relationship,
     ...
   )
 
@@ -482,37 +838,87 @@ inner_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, suffix = NULL,
     pk = join_spec$new_pk,
     fks_in = join_spec$new_fks_in,
     fks_out = join_spec$new_fks_out,
-    uuid = join_spec$new_uuid
+    uuid = join_spec$new_uuid,
+    zoom2 = keyed_get_info(x)$zoom2
   )
 }
 
 #' @export
-full_join.dm <- function(x, ...) {
+full_join.dm <- function(
+  x,
+  y,
+  by = NULL,
+  copy = FALSE,
+  suffix = c(".x", ".y"),
+  ...,
+  keep = NULL,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  relationship = NULL
+) {
   check_zoomed(x)
 }
 
 #' @rdname dplyr_join
 #' @export
-full_join.dm_zoomed <- function(x, y, by = NULL, copy = NULL, suffix = NULL, select = NULL, ...) {
+full_join.dm_zoomed <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  suffix = NULL,
+  ...,
+  keep = NULL,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  relationship = NULL,
+  select = NULL
+) {
   y_name <- as_string(enexpr(y))
   join_data <- prepare_join(x, {{ y }}, by, {{ select }}, suffix, copy)
-  joined_tbl <- full_join(join_data$x_tbl, join_data$y_tbl, join_data$by, copy = FALSE, ...)
+  joined_tbl <- full_join(
+    join_data$x_tbl,
+    join_data$y_tbl,
+    join_data$by,
+    copy = FALSE,
+    ...,
+    keep = keep,
+    na_matches = na_matches,
+    multiple = multiple,
+    relationship = relationship
+  )
   replace_zoomed_tbl(x, joined_tbl, join_data$new_col_names)
 }
 
 #' @rdname dplyr_join
 #' @export
-full_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, suffix = NULL, ..., keep = FALSE) {
+full_join.dm_keyed_tbl <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  suffix = NULL,
+  ...,
+  keep = FALSE,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  relationship = NULL
+) {
   if (!is_dm_keyed_tbl(y)) {
     return(NextMethod())
   }
 
   join_spec <- keyed_build_join_spec(x, y, by, suffix)
   joined_tbl <- full_join(
-    join_spec$x_tbl, join_spec$y_tbl, deframe(join_spec$by),
+    join_spec$x_tbl,
+    join_spec$y_tbl,
+    deframe(join_spec$by),
     copy = copy,
     suffix = join_spec$suffix,
     keep = keep,
+    na_matches = na_matches,
+    multiple = multiple,
+    relationship = relationship,
     ...
   )
 
@@ -521,37 +927,92 @@ full_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, suffix = NULL,
     pk = join_spec$new_pk,
     fks_in = join_spec$new_fks_in,
     fks_out = join_spec$new_fks_out,
-    uuid = join_spec$new_uuid
+    uuid = join_spec$new_uuid,
+    zoom2 = keyed_get_info(x)$zoom2
   )
 }
 
 #' @export
-right_join.dm <- function(x, ...) {
+right_join.dm <- function(
+  x,
+  y,
+  by = NULL,
+  copy = FALSE,
+  suffix = c(".x", ".y"),
+  ...,
+  keep = NULL,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  unmatched = "drop",
+  relationship = NULL
+) {
   check_zoomed(x)
 }
 
 #' @rdname dplyr_join
 #' @export
-right_join.dm_zoomed <- function(x, y, by = NULL, copy = NULL, suffix = NULL, select = NULL, ...) {
+right_join.dm_zoomed <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  suffix = NULL,
+  ...,
+  keep = NULL,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  unmatched = "drop",
+  relationship = NULL,
+  select = NULL
+) {
   y_name <- as_string(enexpr(y))
   join_data <- prepare_join(x, {{ y }}, by, {{ select }}, suffix, copy)
-  joined_tbl <- right_join(join_data$x_tbl, join_data$y_tbl, join_data$by, copy = FALSE, ...)
+  joined_tbl <- right_join(
+    join_data$x_tbl,
+    join_data$y_tbl,
+    join_data$by,
+    copy = FALSE,
+    ...,
+    keep = keep,
+    na_matches = na_matches,
+    multiple = multiple,
+    unmatched = unmatched,
+    relationship = relationship
+  )
   replace_zoomed_tbl(x, joined_tbl, join_data$new_col_names)
 }
 
 #' @rdname dplyr_join
 #' @export
-right_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, suffix = NULL, ..., keep = FALSE) {
+right_join.dm_keyed_tbl <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  suffix = NULL,
+  ...,
+  keep = FALSE,
+  na_matches = c("na", "never"),
+  multiple = "all",
+  unmatched = "drop",
+  relationship = NULL
+) {
   if (!is_dm_keyed_tbl(y)) {
     return(NextMethod())
   }
 
   join_spec <- keyed_build_join_spec(x, y, by, suffix)
   joined_tbl <- right_join(
-    join_spec$x_tbl, join_spec$y_tbl, deframe(join_spec$by),
+    join_spec$x_tbl,
+    join_spec$y_tbl,
+    deframe(join_spec$by),
     copy = copy,
     suffix = join_spec$suffix,
     keep = keep,
+    na_matches = na_matches,
+    multiple = multiple,
+    unmatched = unmatched,
+    relationship = relationship,
     ...
   )
 
@@ -560,27 +1021,51 @@ right_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, suffix = NULL,
     pk = join_spec$new_pk,
     fks_in = join_spec$new_fks_in,
     fks_out = join_spec$new_fks_out,
-    uuid = join_spec$new_uuid
+    uuid = join_spec$new_uuid,
+    zoom2 = keyed_get_info(x)$zoom2
   )
 }
 
 #' @export
-semi_join.dm <- function(x, ...) {
+semi_join.dm <- function(x, y, by = NULL, copy = FALSE, ..., na_matches = c("na", "never")) {
   check_zoomed(x)
 }
 
 #' @rdname dplyr_join
 #' @export
-semi_join.dm_zoomed <- function(x, y, by = NULL, copy = NULL, suffix = NULL, select = NULL, ...) {
+semi_join.dm_zoomed <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  ...,
+  na_matches = c("na", "never"),
+  suffix = NULL,
+  select = NULL
+) {
   y_name <- as_string(enexpr(y))
   join_data <- prepare_join(x, {{ y }}, by, {{ select }}, suffix, copy, disambiguate = FALSE)
-  joined_tbl <- semi_join(join_data$x_tbl, join_data$y_tbl, join_data$by, copy = FALSE, ...)
+  joined_tbl <- semi_join(
+    join_data$x_tbl,
+    join_data$y_tbl,
+    join_data$by,
+    copy = FALSE,
+    ...,
+    na_matches = na_matches
+  )
   replace_zoomed_tbl(x, joined_tbl, join_data$new_col_names)
 }
 
 #' @rdname dplyr_join
 #' @export
-semi_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, ...) {
+semi_join.dm_keyed_tbl <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  ...,
+  na_matches = c("na", "never")
+) {
   if (!is_dm_keyed_tbl(y)) {
     return(NextMethod())
   }
@@ -590,7 +1075,9 @@ semi_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, ...) {
   }
 
   joined_tbl <- semi_join(
-    unclass_keyed_tbl(x), unclass_keyed_tbl(y), by,
+    unclass_keyed_tbl(x),
+    unclass_keyed_tbl(y),
+    by,
     copy = copy,
     ...
   )
@@ -599,22 +1086,45 @@ semi_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, ...) {
 }
 
 #' @export
-anti_join.dm <- function(x, ...) {
+anti_join.dm <- function(x, y, by = NULL, copy = FALSE, ..., na_matches = c("na", "never")) {
   check_zoomed(x)
 }
 
 #' @rdname dplyr_join
 #' @export
-anti_join.dm_zoomed <- function(x, y, by = NULL, copy = NULL, suffix = NULL, select = NULL, ...) {
+anti_join.dm_zoomed <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  ...,
+  na_matches = c("na", "never"),
+  suffix = NULL,
+  select = NULL
+) {
   y_name <- as_string(enexpr(y))
   join_data <- prepare_join(x, {{ y }}, by, {{ select }}, suffix, copy, disambiguate = FALSE)
-  joined_tbl <- anti_join(join_data$x_tbl, join_data$y_tbl, join_data$by, copy = FALSE, ...)
+  joined_tbl <- anti_join(
+    join_data$x_tbl,
+    join_data$y_tbl,
+    join_data$by,
+    copy = FALSE,
+    ...,
+    na_matches = na_matches
+  )
   replace_zoomed_tbl(x, joined_tbl, join_data$new_col_names)
 }
 
 #' @rdname dplyr_join
 #' @export
-anti_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, ...) {
+anti_join.dm_keyed_tbl <- function(
+  x,
+  y,
+  by = NULL,
+  copy = NULL,
+  ...,
+  na_matches = c("na", "never")
+) {
   if (!is_dm_keyed_tbl(y)) {
     return(NextMethod())
   }
@@ -624,7 +1134,9 @@ anti_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, ...) {
   }
 
   joined_tbl <- anti_join(
-    unclass_keyed_tbl(x), unclass_keyed_tbl(y), by,
+    unclass_keyed_tbl(x),
+    unclass_keyed_tbl(y),
+    by,
     copy = copy,
     ...
   )
@@ -633,14 +1145,34 @@ anti_join.dm_keyed_tbl <- function(x, y, by = NULL, copy = NULL, ...) {
 }
 
 #' @export
-nest_join.dm <- function(x, ...) {
+nest_join.dm <- function(
+  x,
+  y,
+  by = NULL,
+  copy = FALSE,
+  keep = NULL,
+  name = NULL,
+  ...,
+  na_matches = c("na", "never"),
+  unmatched = "drop"
+) {
   check_zoomed(x)
 }
 
 #' @rdname dplyr_join
 #' @inheritParams dplyr::nest_join
 #' @export
-nest_join.dm_zoomed <- function(x, y, by = NULL, copy = FALSE, keep = FALSE, name = NULL, ...) {
+nest_join.dm_zoomed <- function(
+  x,
+  y,
+  by = NULL,
+  copy = FALSE,
+  keep = NULL,
+  name = NULL,
+  ...,
+  na_matches = c("na", "never"),
+  unmatched = "drop"
+) {
   y_name <- as_string(enexpr(y))
   name <- name %||% y_name
   join_data <- prepare_join(x, {{ y }}, by, NULL, NULL, NULL, disambiguate = FALSE)
@@ -648,13 +1180,68 @@ nest_join.dm_zoomed <- function(x, y, by = NULL, copy = FALSE, keep = FALSE, nam
   replace_zoomed_tbl(x, joined_tbl, join_data$new_col_names)
 }
 
+#' @export
+cross_join.dm <- function(x, y, ..., copy = FALSE, suffix = c(".x", ".y")) {
+  check_zoomed(x)
+}
+
+#' @rdname dplyr_join
+#' @export
+cross_join.dm_zoomed <- function(x, y, ..., copy = NULL, suffix = c(".x", ".y")) {
+  if (!is_null(copy)) {
+    message("Tables in a `dm` are necessarily on the same `src`, setting `copy = FALSE`.")
+  }
+  y_name <- dm_tbl_name(x, {{ y }})
+  zoomed <- dm_get_zoom(x, c("table", "zoom", "col_tracker_zoom"))
+  x_tbl <- zoomed$zoom[[1]]
+  y_tbl <- dm_get_tables_impl(x)[[y_name]]
+  new_col_names <- zoomed$col_tracker_zoom[[1]]
+  joined_tbl <- cross_join(x_tbl, y_tbl, ..., copy = FALSE, suffix = suffix)
+  replace_zoomed_tbl(x, joined_tbl, new_col_names)
+}
+
+#' @rdname dplyr_join
+#' @export
+cross_join.dm_keyed_tbl <- function(x, y, ..., copy = NULL, suffix = c(".x", ".y")) {
+  if (!is_dm_keyed_tbl(y)) {
+    return(NextMethod())
+  }
+
+  joined_tbl <- cross_join(
+    unclass_keyed_tbl(x),
+    unclass_keyed_tbl(y),
+    ...,
+    copy = copy,
+    suffix = suffix
+  )
+
+  new_keyed_tbl(
+    joined_tbl,
+    uuid = keyed_get_info(x)$uuid,
+    zoom2 = keyed_get_info(x)$zoom2
+  )
+}
+
 #' @autoglobal
-prepare_join <- function(x, y, by, selected, suffix, copy, disambiguate = TRUE) {
+prepare_join <- function(
+  x,
+  y,
+  by,
+  selected,
+  suffix,
+  copy,
+  disambiguate = TRUE,
+  error_call = caller_env()
+) {
   y_name <- dm_tbl_name(x, {{ y }})
   select_quo <- enquo(selected)
 
-  if (!is_null(suffix)) message("Column names are disambiguated if necessary, `suffix` ignored.")
-  if (!is_null(copy)) message("Tables in a `dm` are necessarily on the same `src`, setting `copy = FALSE`.")
+  if (!is_null(suffix)) {
+    message("Column names are disambiguated if necessary, `suffix` ignored.")
+  }
+  if (!is_null(copy)) {
+    message("Tables in a `dm` are necessarily on the same `src`, setting `copy = FALSE`.")
+  }
 
   zoomed <- dm_get_zoom(x, c("table", "zoom", "col_tracker_zoom"))
 
@@ -667,7 +1254,7 @@ prepare_join <- function(x, y, by, selected, suffix, copy, disambiguate = TRUE)
     select_quo <- quo(everything())
   }
 
-  selected <- eval_select_both(select_quo, colnames(y_tbl))$names
+  selected <- eval_select_both(select_quo, colnames(y_tbl), error_call = error_call)$names
 
   new_col_names <- zoomed$col_tracker_zoom[[1]]
 
@@ -678,7 +1265,7 @@ prepare_join <- function(x, y, by, selected, suffix, copy, disambiguate = TRUE)
     if (!all(names(by) %in% new_col_names)) abort_fk_not_tracked(x_orig_name, y_name)
   }
 
-  by <- repair_by(by)
+  by <- normalize_join_by(by)
 
   # selection without RHS `by`; only this is needed for disambiguation and by-columns are added later on for all join-types
   selected_wo_by <- selected[selected %in% setdiff(selected, by)]
@@ -755,7 +1342,14 @@ unique_prefix <- function(x) {
 }
 
 # Workaround for dev dplyr + dbplyr
-safe_count <- function(x, ..., wt = NULL, sort = FALSE, name = NULL, .drop = group_by_drop_default(x)) {
+safe_count <- function(
+  x,
+  ...,
+  wt = NULL,
+  sort = FALSE,
+  name = NULL,
+  .drop = group_by_drop_default(x)
+) {
   quos <- enquos(...)
 
   if (has_length(quos)) {
