@@ -16,26 +16,37 @@
 #' @param view_type Can be "keys_only" (default), "all" or "title_only".
 #'   It defines the level of details for rendering tables
 #'   (only primary and foreign keys, all columns, or no columns).
-#' @param graph_name The name of the graph.
-#' @param graph_attrs Additional graph attributes.
-#' @param node_attrs Additional node attributes.
-#' @param edge_attrs Additional edge attributes.
-#' @param focus A list of parameters for rendering (table filter).
-#' @param columnArrows Edges from columns to columns (default: `TRUE`).
 #' @inheritParams rlang::args_dots_empty
 #' @param column_types Set to `TRUE` to show column types.
 #' @param backend Currently, only the default `"DiagrammeR"` is accepted.
-#'   Pass this value explicitly if your code not only uses this function
-#'   to display a data model but relies on the type of the return value.
-#' @param font_size `r lifecycle::badge("experimental")`
-#'
-#'   Font size for:
-#'
-#'   - `header`, defaults to `16`
-#'   - `column`, defaults to `16`
-#'   - `table_description`, defaults to `8`
-#'
-#'   Can be set as a named integer vector, e.g. `c(table_headers = 18L, table_description = 6L)`.
+#'   Pass this value explicitly if your code relies on the type of the return value.
+#' @param backend_opts A named list of backend-specific options.
+#'   For the `"DiagrammeR"` backend, supported options are:
+#'   - `graph_attrs`: Additional graph attributes (default `""`).
+#'   - `node_attrs`: Additional node attributes (default `""`).
+#'   - `edge_attrs`: Additional edge attributes (default `""`).
+#'   - `focus`: A list of parameters for rendering (table filter).
+#'   - `graph_name`: The name of the graph (default `"Data Model"`).
+#'   - `column_arrow`: Edges from columns to columns (default `TRUE`).
+#'   - `font_size`: `r lifecycle::badge("experimental")`
+#'     Font size for `header` (default `16`), `column` (default `16`),
+#'     and `table_description` (default `8`).
+#'     Can be set as a named integer vector, e.g.
+#'     `c(table_headers = 18L, table_description = 6L)`.
+#' @param columnArrows `r lifecycle::badge("deprecated")` Use
+#'   `backend_opts = list(column_arrow = ...)` instead.
+#' @param graph_attrs `r lifecycle::badge("deprecated")` Use
+#'   `backend_opts = list(graph_attrs = ...)` instead.
+#' @param node_attrs `r lifecycle::badge("deprecated")` Use
+#'   `backend_opts = list(node_attrs = ...)` instead.
+#' @param edge_attrs `r lifecycle::badge("deprecated")` Use
+#'   `backend_opts = list(edge_attrs = ...)` instead.
+#' @param focus `r lifecycle::badge("deprecated")` Use
+#'   `backend_opts = list(focus = ...)` instead.
+#' @param graph_name `r lifecycle::badge("deprecated")` Use
+#'   `backend_opts = list(graph_name = ...)` instead.
+#' @param font_size `r lifecycle::badge("deprecated")` Use
+#'   `backend_opts = list(font_size = ...)` instead.
 #'
 #' @seealso [dm_set_colors()] for defining the table colors.
 #' @seealso [dm_set_table_description()] for adding details to one or more tables in the diagram
@@ -59,37 +70,123 @@
 #'
 #' dm_nycflights13() %>%
 #'   dm_get_colors()
-dm_draw <- function(dm,
-                    rankdir = "LR",
-                    ...,
-                    col_attr = NULL,
-                    view_type = c("keys_only", "all", "title_only"),
-                    columnArrows = TRUE,
-                    graph_attrs = "",
-                    node_attrs = "",
-                    edge_attrs = "",
-                    focus = NULL,
-                    graph_name = "Data Model",
-                    column_types = NULL,
-                    backend = "DiagrammeR",
-                    font_size = NULL) {
+dm_draw <- function(
+  dm,
+  rankdir = "LR",
+  ...,
+  col_attr = NULL,
+  view_type = c("keys_only", "all", "title_only"),
+  column_types = NULL,
+  backend = c("DiagrammeR"),
+  backend_opts = list(),
+  columnArrows = lifecycle::deprecated(),
+  graph_attrs = lifecycle::deprecated(),
+  node_attrs = lifecycle::deprecated(),
+  edge_attrs = lifecycle::deprecated(),
+  focus = lifecycle::deprecated(),
+  graph_name = lifecycle::deprecated(),
+  font_size = lifecycle::deprecated()
+) {
+  dm_local_error_call()
   check_not_zoomed(dm)
   check_dots_empty()
 
+  # Handle deprecated DiagrammeR-specific arguments
+  if (lifecycle::is_present(columnArrows)) {
+    lifecycle::deprecate_soft(
+      "1.1.0",
+      "dm_draw(columnArrows = )",
+      details = "Use `backend_opts = list(column_arrow = ...)` instead."
+    )
+    backend_opts[["column_arrow"]] <- backend_opts[["column_arrow"]] %||% columnArrows
+  }
+  if (lifecycle::is_present(graph_attrs)) {
+    lifecycle::deprecate_soft(
+      "1.1.0",
+      "dm_draw(graph_attrs = )",
+      details = "Use `backend_opts = list(graph_attrs = ...)` instead."
+    )
+    backend_opts[["graph_attrs"]] <- backend_opts[["graph_attrs"]] %||% graph_attrs
+  }
+  if (lifecycle::is_present(node_attrs)) {
+    lifecycle::deprecate_soft(
+      "1.1.0",
+      "dm_draw(node_attrs = )",
+      details = "Use `backend_opts = list(node_attrs = ...)` instead."
+    )
+    backend_opts[["node_attrs"]] <- backend_opts[["node_attrs"]] %||% node_attrs
+  }
+  if (lifecycle::is_present(edge_attrs)) {
+    lifecycle::deprecate_soft(
+      "1.1.0",
+      "dm_draw(edge_attrs = )",
+      details = "Use `backend_opts = list(edge_attrs = ...)` instead."
+    )
+    backend_opts[["edge_attrs"]] <- backend_opts[["edge_attrs"]] %||% edge_attrs
+  }
+  if (lifecycle::is_present(focus)) {
+    lifecycle::deprecate_soft(
+      "1.1.0",
+      "dm_draw(focus = )",
+      details = "Use `backend_opts = list(focus = ...)` instead."
+    )
+    backend_opts[["focus"]] <- backend_opts[["focus"]] %||% focus
+  }
+  if (lifecycle::is_present(graph_name)) {
+    lifecycle::deprecate_soft(
+      "1.1.0",
+      "dm_draw(graph_name = )",
+      details = "Use `backend_opts = list(graph_name = ...)` instead."
+    )
+    backend_opts[["graph_name"]] <- backend_opts[["graph_name"]] %||% graph_name
+  }
+  if (lifecycle::is_present(font_size)) {
+    lifecycle::deprecate_soft(
+      "1.1.0",
+      "dm_draw(font_size = )",
+      details = "Use `backend_opts = list(font_size = ...)` instead."
+    )
+    backend_opts[["font_size"]] <- backend_opts[["font_size"]] %||% font_size
+  }
+
   tbl_names <- src_tbls_impl(dm, quiet = TRUE)
-  table_description <- dm_get_table_description_impl(dm, set_names(seq_along(tbl_names), tbl_names)) %>%
+  table_description <- dm_get_table_description_impl(
+    dm,
+    set_names(seq_along(tbl_names), tbl_names)
+  ) %>%
     prep_recode()
 
   view_type <- arg_match(view_type)
 
   if (!is.null(col_attr)) {
-    deprecate_soft("0.1.13", "dm::dm_draw(col_attr = )", "dm::dm_draw(column_types = )")
+    deprecate_warn("0.1.13", "dm::dm_draw(col_attr = )", "dm::dm_draw(column_types = )")
     if (is.null(column_types) && "type" %in% col_attr) {
       column_types <- TRUE
     }
   }
 
-  stopifnot(identical(backend, "DiagrammeR"))
+  backend <- arg_match(backend)
+
+  supported_backend_opts <- c(
+    "graph_attrs",
+    "node_attrs",
+    "edge_attrs",
+    "focus",
+    "graph_name",
+    "column_arrow",
+    "font_size"
+  )
+  unsupported <- setdiff(names(backend_opts), supported_backend_opts)
+  if (length(unsupported) > 0) {
+    cli::cli_abort(
+      c(
+        "Unsupported {.arg backend_opts} for backend {.val {backend}}: {.field {unsupported}}.",
+        i = "Supported options are: {.field {supported_backend_opts}}."
+      ),
+      class = dm_error_full("unsupported_backend_opts"),
+      call = dm_error_call()
+    )
+  }
 
   if (is_empty(dm)) {
     message("The dm cannot be drawn because it is empty.")
@@ -100,19 +197,20 @@ dm_draw <- function(dm,
 
   data_model <- dm_get_data_model(dm, column_types)
 
+  # DiagrammeR backend (default)
   graph <- bdm_create_graph(
     data_model,
     rankdir = rankdir,
     col_attr = c("column", if (column_types) "type"),
     view_type = view_type,
-    columnArrows = columnArrows,
-    graph_attrs = graph_attrs,
-    node_attrs = node_attrs,
-    edge_attrs = edge_attrs,
-    focus = focus,
-    graph_name = graph_name,
+    columnArrows = backend_opts[["column_arrow"]] %||% TRUE,
+    graph_attrs = backend_opts[["graph_attrs"]] %||% "",
+    node_attrs = backend_opts[["node_attrs"]] %||% "",
+    edge_attrs = backend_opts[["edge_attrs"]] %||% "",
+    focus = backend_opts[["focus"]],
+    graph_name = backend_opts[["graph_name"]] %||% "Data Model",
     table_description = as.list(table_description),
-    font_size = as.list(font_size)
+    font_size = as.list(backend_opts[["font_size"]])
   )
   bdm_render_graph(graph, top_level_fun = "dm_draw")
 }
@@ -256,11 +354,16 @@ dm_get_all_column_types <- function(x) {
 #'   dm_draw()
 #' @autoglobal
 dm_set_colors <- function(dm, ...) {
+  dm_local_error_call()
   quos <- enquos(...)
-  if (any(names(quos) == "")) abort_only_named_args("dm_set_colors", "the colors")
+  if (any(names(quos) == "")) {
+    abort_only_named_args("dm_set_colors", "the colors")
+  }
   cols <- names(quos)
-  if (!all(cols[!is_hex_color(cols)] %in% dm_get_available_colors()) &&
-    all(cols %in% src_tbls_impl(dm))) {
+  if (
+    !all(cols[!is_hex_color(cols)] %in% dm_get_available_colors()) &&
+      all(cols %in% src_tbls_impl(dm))
+  ) {
     abort_wrong_syntax_set_cols()
   }
 
