@@ -11,6 +11,9 @@
 #' @param .progress Whether to display a progress bar, if `NA` (the default)
 #'   hide in non-interactive mode, show in interactive mode. Requires the
 #'   'progress' package.
+#' @param .max_value Maximum number of distinct problematic values to report
+#'   in the `problem` column, defaults to `6`.
+#'   Set to `Inf` to report all values.
 #' @param dm,progress `r lifecycle::badge("deprecated")`
 #'
 #' @return A tibble with the following columns:
@@ -32,36 +35,71 @@
 #' dm_nycflights13() %>%
 #'   dm_examine_constraints()
 #' @autoglobal
-dm_examine_constraints <- function(.dm, ..., .progress = NA,
-                                   dm = deprecated(), progress = deprecated()) {
+dm_examine_constraints <- function(
+  .dm,
+  ...,
+  .progress = NA,
+  .max_value = 6L,
+  dm = deprecated(),
+  progress = deprecated()
+) {
   check_dots_empty()
+  dm_local_error_call()
 
   if (!is_missing(dm)) {
-    deprecate_soft("1.0.0", "dm_examine_constraints(dm = )", "dm_examine_constraints(.dm = )")
+    deprecate_warn("1.0.0", "dm_examine_constraints(dm = )", "dm_examine_constraints(.dm = )")
   }
 
   if (is_missing(.dm)) {
-    return(dm_examine_constraints(dm, .progress = .progress, progress = progress))
+    return(dm_examine_constraints(
+      dm,
+      .progress = .progress,
+      .max_value = .max_value,
+      progress = progress
+    ))
   }
 
   if (!is_missing(progress)) {
     if (is.na(progress)) {
       progress <- .progress
     }
-    deprecate_soft("1.0.0", "dm_examine_constraints(progress = )", "dm_examine_constraints(.progress = )")
+    deprecate_warn(
+      "1.0.0",
+      "dm_examine_constraints(progress = )",
+      "dm_examine_constraints(.progress = )"
+    )
   }
 
   check_not_zoomed(.dm)
   .dm %>%
-    dm_examine_constraints_impl(progress = .progress, top_level_fun = "dm_examine_constraints") %>%
+    dm_examine_constraints_impl(
+      progress = .progress,
+      top_level_fun = "dm_examine_constraints",
+      max_value = .max_value
+    ) %>%
     rename(columns = column) %>%
     mutate(columns = new_keys(columns)) %>%
     new_dm_examine_constraints()
 }
 
-dm_examine_constraints_impl <- function(dm, progress = NA, top_level_fun = NULL) {
-  pk_results <- check_pk_constraints(dm, progress, top_level_fun = top_level_fun)
-  fk_results <- check_fk_constraints(dm, progress, top_level_fun = top_level_fun)
+dm_examine_constraints_impl <- function(
+  dm,
+  progress = NA,
+  top_level_fun = NULL,
+  max_value = MAX_COMMAS
+) {
+  pk_results <- check_pk_constraints(
+    dm,
+    progress,
+    top_level_fun = top_level_fun,
+    max_value = max_value
+  )
+  fk_results <- check_fk_constraints(
+    dm,
+    progress,
+    top_level_fun = top_level_fun,
+    max_value = max_value
+  )
   bind_rows(
     pk_results,
     fk_results
@@ -96,13 +134,19 @@ print.dm_examine_constraints <- function(x, ...) {
         into = if_else(kind == "FK", paste0(" into table ", tick(ref_table)), "")
       ) %>%
       # FIXME: Use cli styles
-      mutate(text = paste0(
-        "Table ", tick(table), ": ",
-        kind_to_long(kind), " ",
-        format(map(problem_df$columns, tick), justify = "none"),
-        into,
-        ": ", problem
-      )) %>%
+      mutate(
+        text = paste0(
+          "Table ",
+          tick(table),
+          ": ",
+          kind_to_long(kind),
+          " ",
+          format(map(problem_df$columns, tick), justify = "none"),
+          into,
+          ": ",
+          problem
+        )
+      ) %>%
       pull(text) %>%
       cli::cat_bullet(bullet_col = "red")
   }
@@ -121,9 +165,12 @@ kind_to_long <- function(kind) {
 }
 
 #' @autoglobal
-check_pk_constraints <- function(dm, progress = NA, top_level_fun = NULL) {
+check_pk_constraints <- function(dm, progress = NA, top_level_fun = NULL, max_value = MAX_COMMAS) {
   pks <- bind_rows(
-    list(PK = dm_get_all_pks_impl(dm), UK = dm_get_all_uks_impl(dm) %>% rename(pk_col = uk_col) %>% select(-kind)),
+    list(
+      PK = dm_get_all_pks_impl(dm),
+      UK = dm_get_all_uks_impl(dm) %>% rename(pk_col = uk_col) %>% select(-kind)
+    ),
     .id = "kind"
   ) %>%
     distinct(table, pk_col, .keep_all = TRUE)
@@ -147,14 +194,23 @@ check_pk_constraints <- function(dm, progress = NA, top_level_fun = NULL) {
     top_level_fun = top_level_fun
   )
 
-  candidates <- map2(set_names(table_names), columns, ticker(~ {
-    tbl <- tbl_impl(dm, .x)
-    enum_pk_candidates_impl(tbl, list(.y))
-  }))
+  candidates <- map2(
+    set_names(table_names),
+    columns,
+    ticker(
+      ~ {
+        tbl <- tbl_impl(dm, .x)
+        enum_pk_candidates_impl(tbl, list(.y), max_value = max_value)
+      }
+    )
+  )
 
   tbl_is_pk <-
     tibble(table = table_names, candidate = candidates) %>%
-    unnest_df("candidate", tibble(column = new_keys(), candidate = logical(), why = character())) %>%
+    unnest_df(
+      "candidate",
+      tibble(column = new_keys(), candidate = logical(), why = character())
+    ) %>%
     rename(is_key = candidate, problem = why)
 
   tibble(
@@ -167,13 +223,20 @@ check_pk_constraints <- function(dm, progress = NA, top_level_fun = NULL) {
 }
 
 #' @autoglobal
-check_fk_constraints <- function(dm, progress = NA, top_level_fun = NULL) {
+check_fk_constraints <- function(dm, progress = NA, top_level_fun = NULL, max_value = MAX_COMMAS) {
   fks <- dm_get_all_fks_impl(dm)
   pts <- map(fks$parent_table, tbl_impl, dm = dm)
   cts <- map(fks$child_table, tbl_impl, dm = dm)
   fks_tibble <-
     mutate(fks, t1 = cts, t2 = pts) %>%
-    select(t1, t1_name = child_table, colname = child_fk_cols, t2, t2_name = parent_table, pk = parent_key_cols)
+    select(
+      t1,
+      t1_name = child_table,
+      colname = child_fk_cols,
+      t2,
+      t2_name = parent_table,
+      pk = parent_key_cols
+    )
 
   ticker <- new_ticker(
     "checking fk constraints",
@@ -184,7 +247,7 @@ check_fk_constraints <- function(dm, progress = NA, top_level_fun = NULL) {
 
   fks_tibble %>%
     mutate(
-      problem = pmap_chr(fks_tibble, ticker(check_fk)),
+      problem = pmap_chr(fks_tibble, ticker(check_fk), max_value = max_value),
       is_key = (problem == ""),
       kind = "FK"
     ) %>%
