@@ -53,29 +53,40 @@
 #' # only the three New York airports.
 #' @export
 dm_filter <- function(.dm, ...) {
+  dm_local_error_call()
   dm_filter_api0({{ .dm }}, ..., target = dm_filter_impl0, apply_target = dm_apply_filters_impl)
 }
 
-dm_filter_api0 <- function(..., dm = NULL,
-                           call = caller_env(), user_env = caller_env(2),
-                           target = make_dm_filter_api_call,
-                           apply_target = make_dm_apply_filters_call) {
+dm_filter_api0 <- function(
+  ...,
+  dm = NULL,
+  call = caller_env(),
+  user_env = caller_env(2),
+  target = make_dm_filter_api_call,
+  apply_target = make_dm_apply_filters_call
+) {
   if (!is.null(dm)) {
-    deprecate_soft("1.0.0", "dm_filter(dm = )", "dm_filter(.dm = )", user_env = user_env)
+    deprecate_warn("1.0.0", "dm_filter(dm = )", "dm_filter(.dm = )", user_env = user_env)
     dm_filter_api1(
-      dm, ...,
-      call = call, user_env = user_env, target = target, apply_target = apply_target
+      dm,
+      ...,
+      call = call,
+      user_env = user_env,
+      target = target,
+      apply_target = apply_target
     )
   } else {
     dm_filter_api1(
       ...,
-      call = call, user_env = user_env, target = target, apply_target = apply_target
+      call = call,
+      user_env = user_env,
+      target = target,
+      apply_target = apply_target
     )
   }
 }
 
-dm_filter_api1 <- function(.dm, ..., table = NULL,
-                           call, user_env, target, apply_target) {
+dm_filter_api1 <- function(.dm, ..., table = NULL, call, user_env, target, apply_target) {
   quos <- enquos(...)
   table <- enquo(table)
 
@@ -84,7 +95,9 @@ dm_filter_api1 <- function(.dm, ..., table = NULL,
     out <- reduce2(names(quos), quos, dm_filter_api, .init = .dm, target = target)
     apply_target(out)
   } else {
-    deprecate_soft("1.0.0", "dm_filter(table = )",
+    deprecate_warn(
+      "1.0.0",
+      "dm_filter(table = )",
       user_env = user_env,
       details = "`dm_filter()` now takes named filter expressions, the names correspond to the tables to be filtered. You no longer need to call `dm_apply_filters()` to materialize the filters."
     )
@@ -161,7 +174,9 @@ dm_apply_filters <- function(dm) {
 
   filters <- dm_get_filters_impl(dm)
   if (nrow(filters) == 0) {
-    deprecate_soft("1.0.0", "dm_apply_filters()",
+    deprecate_warn(
+      "1.0.0",
+      "dm_apply_filters()",
       details = "Calling `dm_apply_filters()` after `dm_filter()` is no longer necessary."
     )
   }
@@ -184,7 +199,9 @@ dm_apply_filters_to_tbl <- function(dm, table) {
 
   filters <- dm_get_filters_impl(dm)
   if (nrow(filters) == 0) {
-    deprecate_soft("1.0.0", "dm_apply_filters_to_tbl()",
+    deprecate_warn(
+      "1.0.0",
+      "dm_apply_filters_to_tbl()",
       details = "Access tables directly after `dm_filter()`."
     )
   }
@@ -232,7 +249,8 @@ dm_get_filtered_table <- function(dm, from) {
       semi_joins <- pull(semi_joins)
       semi_joins_tbls <- list_of_tables[semi_joins]
       table <-
-        reduce2(semi_joins_tbls,
+        reduce2(
+          semi_joins_tbls,
           semi_joins,
           ~ semi_join(..1, ..2, by = get_by(dm, table_name, ..3)),
           .init = table
@@ -286,7 +304,9 @@ dm_get_filters <- function(dm) {
 
   filters <- dm_get_filters_impl(dm)
   if (nrow(filters) == 0) {
-    deprecate_soft("1.0.0", "dm_get_filters()",
+    deprecate_warn(
+      "1.0.0",
+      "dm_get_filters()",
       details = "Filter conditions are no longer stored with the dm object."
     )
   }
@@ -317,7 +337,7 @@ get_all_filtered_connected <- function(dm, table) {
   # Computation of distances and shortest paths uses the same algorithm
   # internally, but s.p. doesn't return distances and distances don't return
   # the predecessor.
-  distances <- igraph::distances(graph, table)[1, ]
+  distances <- graph_distances(graph, table)[1, ]
   finite_distances <- distances[is.finite(distances)]
 
   # Using only nodes with finite distances (=in the same connected component)
@@ -331,14 +351,16 @@ get_all_filtered_connected <- function(dm, table) {
   # use only subgraph to
   # 1. speed things up
   # 2. make it possible to easily test for a cycle (cycle if: N(E) >= N(V))
-  graph <- igraph::induced_subgraph(graph, target_tables)
-  if (length(E(graph)) >= length(V(graph))) abort_no_cycles(graph)
-  paths <- igraph::shortest_paths(graph, table, target_tables, predecessors = TRUE)
+  graph <- graph_induced_subgraph(graph, target_tables)
+  if (length(graph_edges(graph)) >= length(graph_vertices(graph))) {
+    abort_no_cycles(graph)
+  }
+  paths <- graph_shortest_paths(graph, table, target_tables, predecessors = TRUE)
 
   # All edges with finite distance as tidy data frame
   all_edges <-
     new_filtered_edges(
-      node = names(V(graph)),
+      node = names(graph_vertices(graph)),
       parent = names(paths$predecessors),
       # all of `graph`, `paths` and `finite_distances` are based on the same subset of tables,
       # hence the resulting tibble is correct
@@ -358,7 +380,9 @@ get_all_filtered_connected <- function(dm, table) {
   # Recursive join
   repeat {
     missing <- setdiff(edges$parent, edges$node)
-    if (is_empty(missing)) break
+    if (is_empty(missing)) {
+      break
+    }
 
     edges <- bind_rows(edges, filter(all_edges, node %in% !!missing))
   }
