@@ -61,20 +61,40 @@
 #'
 #' @export
 dm_flatten_to_tbl <- function(dm, .start, ..., .recursive = FALSE, .join = left_join) {
+  dm_local_error_call()
   check_not_zoomed(dm)
   join_name <- as_label(enexpr(.join))
-  if (.recursive && !(join_name %in% c("left_join", "full_join", "inner_join"))) abort_squash_limited()
+  if (.recursive && !(join_name %in% c("left_join", "full_join", "inner_join"))) {
+    abort_squash_limited()
+  }
 
   start <- dm_tbl_name(dm, {{ .start }})
 
   vars <- setdiff(src_tbls_impl(dm), start)
   list_of_pts <- eval_select_table(quo(c(...)), vars)
 
-  dm_flatten_to_tbl_impl(dm, start, list_of_pts, join = .join, join_name = join_name, squash = .recursive)
+  dm_flatten_to_tbl_impl(
+    dm,
+    start,
+    list_of_pts,
+    join = .join,
+    join_name = join_name,
+    squash = .recursive
+  )
 }
 
-dm_flatten_to_tbl_impl <- function(dm, start, list_of_pts, join, join_name, squash, .position = "suffix") {
-  if (join_name == "nest_join") abort_no_flatten_with_nest_join()
+dm_flatten_to_tbl_impl <- function(
+  dm,
+  start,
+  list_of_pts,
+  join,
+  join_name,
+  squash,
+  .position = "suffix"
+) {
+  if (join_name == "nest_join") {
+    abort_no_flatten_with_nest_join()
+  }
 
   force(join)
   stopifnot(is_function(join))
@@ -97,25 +117,24 @@ dm_flatten_to_tbl_impl <- function(dm, start, list_of_pts, join, join_name, squa
     list_of_pts <- get_names_of_connected(g, start, squash)
   }
   # We use the induced subgraph right away
-  g <- igraph::induced_subgraph(g, c(start, list_of_pts))
+  g <- graph_induced_subgraph(g, c(start, list_of_pts))
 
   # each next table needs to be accessible from the former table (note: directed relations)
   # we achieve this with a depth-first-search (DFS) with param `unreachable = FALSE`
-  dfs <- igraph::dfs(g, start, unreachable = FALSE, father = TRUE, dist = TRUE)
+  dfs <- graph_dfs(g, start, unreachable = FALSE, parent = TRUE, dist = TRUE)
 
   # compute all table names
   order_df <-
     tibble(
       name = names(dfs[["order"]]),
-      pred = names(V(g))[unclass(dfs[["father"]])[name]]
+      pred = names(graph_vertices(g))[unclass(dfs[["parent"]])[name]]
     )
 
   # function to detect any reason for abort()
   check_flatten_to_tbl(
     join_name,
     (nrow(dm_get_filters_impl(dm)) > 0) && !is_empty(list_of_pts),
-    # igraph 2.0.0
-    anyNA(order_df$name) || nrow(order_df) < igraph::vcount(g),
+    anyNA(order_df$name) || nrow(order_df) < graph_vcount(g),
     g,
     auto_detect,
     nrow(order_df) > 2,
@@ -154,7 +173,8 @@ dm_flatten_to_tbl_impl <- function(dm, start, list_of_pts, join, join_name, squa
 #' @rdname deprecated
 #' @export
 dm_join_to_tbl <- function(dm, table_1, table_2, join = left_join) {
-  deprecate_soft("0.3.0", "dm::dm_join_to_tbl()", "dm::dm_flatten_to_tbl()")
+  dm_local_error_call()
+  deprecate_warn("0.3.0", "dm::dm_join_to_tbl()", "dm::dm_flatten_to_tbl()")
 
   check_not_zoomed(dm)
   force(join)
@@ -168,7 +188,15 @@ dm_join_to_tbl <- function(dm, table_1, table_2, join = left_join) {
   start <- rel$child_table
   other <- rel$parent_table
 
-  dm_flatten_to_tbl_impl(dm, start, other, join = join, join_name = join_name, squash = FALSE, .position = "prefix")
+  dm_flatten_to_tbl_impl(
+    dm,
+    start,
+    other,
+    join = join,
+    join_name = join_name,
+    squash = FALSE,
+    .position = "prefix"
+  )
 }
 
 parent_child_table <- function(dm, table_1, table_2) {
@@ -193,14 +221,16 @@ parent_child_table <- function(dm, table_1, table_2) {
   rel
 }
 
-check_flatten_to_tbl <- function(join_name,
-                                 part_cond_abort_filters,
-                                 any_not_reachable,
-                                 g,
-                                 auto_detect,
-                                 more_than_1_pt,
-                                 has_grandparent,
-                                 squash) {
+check_flatten_to_tbl <- function(
+  join_name,
+  part_cond_abort_filters,
+  any_not_reachable,
+  g,
+  auto_detect,
+  more_than_1_pt,
+  has_grandparent,
+  squash
+) {
   # argument checking, or filter and recompute induced subgraph
   # for subsequent check
   if (any_not_reachable) {
@@ -208,19 +238,22 @@ check_flatten_to_tbl <- function(join_name,
   }
 
   # Cycles not yet supported
-  if (length(V(g)) - 1 != length(E(g))) {
+  if (length(graph_vertices(g)) - 1 != length(graph_edges(g))) {
     abort_no_cycles(g)
   }
-  if (join_name == "nest_join") abort_no_flatten_with_nest_join()
-  if (part_cond_abort_filters && join_name %in% c("full_join", "right_join")) abort_apply_filters_first(join_name)
+  if (join_name == "nest_join") {
+    abort_no_flatten_with_nest_join()
+  }
+  if (part_cond_abort_filters && join_name %in% c("full_join", "right_join")) {
+    abort_apply_filters_first(join_name)
+  }
   # the result for `right_join()` depends on the order of the dim-tables in the `dm`
   # if 2 or more of them are joined to the fact table and ellipsis is empty.
 
-
-  # If called by `dm_join_to_tbl()` or `dm_flatten_to_tbl()`, the argument `squash = FALSE`.
+  # If called by `dm_join_to_tbl()` or `dm_flatten_to_tbl()` with `.recursive = FALSE`.
   # Then only one level of hierarchy is allowed (direct neighbors to table `.start`).
   if (!squash && has_grandparent) {
-    abort_only_parents()
+    abort_only_parents("dm_join_to_tbl", ".start", ".recursive")
   }
 
   if (join_name == "right_join" && auto_detect && more_than_1_pt) {
