@@ -8,7 +8,7 @@
 #' @rdname deprecated
 #' @export
 dm_is_referenced <- function(dm, table) {
-  deprecate_soft("0.3.0", "dm::dm_is_referenced()", "dm::dm_get_all_fks()")
+  deprecate_warn("0.3.0", "dm::dm_is_referenced()", "dm::dm_get_all_fks()")
 
   check_not_zoomed(dm)
   has_length(dm_get_referencing_tables(dm, !!ensym(table)))
@@ -24,7 +24,7 @@ dm_is_referenced <- function(dm, table) {
 #'
 #' @export
 dm_get_referencing_tables <- function(dm, table) {
-  deprecate_soft("0.3.0", "dm::dm_get_referencing_tables()", "dm::dm_get_all_fks()")
+  deprecate_warn("0.3.0", "dm::dm_get_referencing_tables()", "dm::dm_get_all_fks()")
 
   check_not_zoomed(dm)
   table <- dm_tbl_name(dm, {{ table }})
@@ -41,11 +41,11 @@ create_graph_from_dm <- function(dm, directed = FALSE) {
     select(ref_table = table, fks) %>%
     unnest_list_of_df("fks") %>%
     select(table, ref_table) %>%
-    igraph::graph_from_data_frame(directed = directed, vertices = def$table)
+    graph_from_data_frame(directed = directed, vertices = def$table)
 }
 
 get_names_of_connected <- function(g, start, squash) {
-  dfs <- igraph::dfs(g, start, unreachable = FALSE, dist = TRUE)
+  dfs <- graph_dfs(g, start, unreachable = FALSE, dist = TRUE)
   # `purrr::discard()` in case `list_of_pts` is `NA`
   if (squash) {
     setdiff(names(dfs[["order"]]), start) %>% discard(is.na)
