@@ -21,7 +21,15 @@ json_nest_join <- function(x, y, by = NULL, ..., copy = FALSE, keep = FALSE, nam
 }
 
 #' @export
-json_nest_join.data.frame <- function(x, y, by = NULL, ..., copy = FALSE, keep = FALSE, name = NULL) {
+json_nest_join.data.frame <- function(
+  x,
+  y,
+  by = NULL,
+  ...,
+  copy = FALSE,
+  keep = FALSE,
+  name = NULL
+) {
   check_suggested("jsonlite", "json_nest_join")
   check_dots_empty()
 
