@@ -21,9 +21,18 @@ json_pack_join <- function(x, y, by = NULL, ..., copy = FALSE, keep = FALSE, nam
 }
 
 #' @export
-json_pack_join.data.frame <- function(x, y, by = NULL, ..., copy = FALSE, keep = FALSE, name = NULL) {
-  check_suggested("jsonlite", use = TRUE, top_level_fun = "json_pack_join")
+json_pack_join.data.frame <- function(
+  x,
+  y,
+  by = NULL,
+  ...,
+  copy = FALSE,
+  keep = FALSE,
+  name = NULL
+) {
+  check_suggested("jsonlite", "json_pack_join")
   check_dots_empty()
+
   name_var <- name %||% as_label(enexpr(y))
   pack_join(x, y, by, ..., copy = copy, keep = keep, name = name_var) %>%
     mutate(
