@@ -24,8 +24,9 @@
 #' check_key(data, a, c)
 #' check_key(data)
 check_key <- function(x, ..., .data = deprecated()) {
+  dm_local_error_call()
   if (!is_missing(.data)) {
-    deprecate_soft("1.0.0", "check_key(.data = )", "check_key(x = )")
+    deprecate_warn("1.0.0", "check_key(.data = )", "check_key(x = )")
     return(check_key_impl0({{ .data }}, {{ x }}, ...))
   }
 
@@ -34,13 +35,15 @@ check_key <- function(x, ..., .data = deprecated()) {
 
 check_key_impl <- function(.data, ...) {
   data_q <- enquo(.data)
-  .data <- eval_tidy(data_q)
+  original_data <- eval_tidy(data_q)
 
+  selected_data <- original_data
   if (dots_n(...) > 0) {
-    .data <- .data %>% select(...)
+    selected_data <- selected_data %>% select(...)
   }
 
-  check_key_impl0(.data, as_label(data_q))
+  check_key_impl0(selected_data, as_label(data_q))
+  invisible(original_data)
 }
 
 check_key_impl0 <- function(x, x_label) {
@@ -74,7 +77,7 @@ is_unique_key <- function(.data, column) {
 }
 
 #' @autoglobal
-is_unique_key_se <- function(.data, colname) {
+is_unique_key_se <- function(.data, colname, max_value = MAX_COMMAS) {
   val_names <- paste0("value", seq_along(colname))
   col_syms <- syms(colname)
   names(col_syms) <- val_names
@@ -101,12 +104,14 @@ is_unique_key_se <- function(.data, colname) {
     mutate(any_na = if_else(!!any_value_na_expr, 1L, 0L)) %>%
     filter(n != 1 | any_na != 0L) %>%
     arrange(desc(n), !!!syms(val_names)) %>%
-    utils::head(MAX_COMMAS + 1) %>%
+    utils::head(max_value + 1) %>%
     collect()
 
   res_tbl[val_names] <- map(res_tbl[val_names], format, trim = TRUE, justify = "none")
   res_tbl[val_names[-1]] <- map(res_tbl[val_names[-1]], ~ paste0(", ", .x))
-  res_tbl$value <- if_else(res_tbl$any_na != 0, NA_character_, exec(paste0, !!!res_tbl[val_names]))
+  # Work around bit64 incompatibility
+  res_tbl$value <- NA_character_
+  res_tbl$value[res_tbl$any_na == 0] <- exec(paste0, !!!res_tbl[res_tbl$any_na == 0, val_names])
 
   duplicate_rows <-
     res_tbl %>%
@@ -151,12 +156,12 @@ is_unique_key_se <- function(.data, colname) {
 #' check_set_equality(data_1, data_3, x_select = a, y_select = a)
 #' # this is still failing:
 #' try(check_set_equality(data_2, data_3))
-check_set_equality <- function(x, y,
-                               ...,
-                               x_select = NULL, y_select = NULL,
-                               by_position = NULL) {
+check_set_equality <- function(x, y, ..., x_select = NULL, y_select = NULL, by_position = NULL) {
+  dm_local_error_call()
   check_api(
-    {{ x }}, {{ y }}, ...,
+    {{ x }},
+    {{ y }},
+    ...,
     x_select = {{ x_select }},
     y_select = {{ y_select }},
     by_position = by_position,
@@ -210,12 +215,12 @@ check_set_equality_impl0 <- function(x, y, x_label, y_label) {
 #'
 #' # this is failing:
 #' try(check_subset(data_2, data_1))
-check_subset <- function(x, y,
-                         ...,
-                         x_select = NULL, y_select = NULL,
-                         by_position = NULL) {
+check_subset <- function(x, y, ..., x_select = NULL, y_select = NULL, by_position = NULL) {
+  dm_local_error_call()
   check_api(
-    {{ x }}, {{ y }}, ...,
+    {{ x }},
+    {{ y }},
+    ...,
     x_select = {{ x_select }},
     y_select = {{ y_select }},
     by_position = by_position,
@@ -254,15 +259,22 @@ is_subset_se <- function(x, y) {
   pull(count(head(res, 1))) == 0
 }
 
-check_api <- function(x, y,
-                      ...,
-                      x_select = NULL, y_select = NULL,
-                      by_position = NULL,
-                      call = caller_env(),
-                      target = list) {
+check_api <- function(
+  x,
+  y,
+  ...,
+  x_select = NULL,
+  y_select = NULL,
+  by_position = NULL,
+  call = caller_env(),
+  target = list
+) {
   if (dots_n(...) >= 2) {
     name <- as.character(frame_call(call)[[1]] %||% "check_api")
-    deprecate_soft("1.0.0", paste0(name, "(c1 = )"), paste0(name, "(x_select = )"),
+    deprecate_warn(
+      "1.0.0",
+      paste0(name, "(c1 = )"),
+      paste0(name, "(x_select = )"),
       details = c(
         "Use `y_select` instead of `c2`, and `x` and `y` instead of `t1` and `t2`.",
         "Using `by_position = TRUE` for compatibility."
@@ -270,14 +282,19 @@ check_api <- function(x, y,
     )
     stopifnot(is.null(by_position))
     check_api_impl(
-      {{ x }}, {{ y }}, ...,
+      {{ x }},
+      {{ y }},
+      ...,
       by_position = TRUE,
       target = target
     )
   } else {
     check_dots_empty(call = call)
     check_api_impl(
-      {{ x }}, {{ x_select }}, {{ y }}, {{ y_select }},
+      {{ x }},
+      {{ x_select }},
+      {{ y }},
+      {{ y_select }},
       by_position = by_position %||% FALSE,
       target = target
     )
@@ -302,7 +319,10 @@ check_api_impl <- function(t1, c1, t2, c2, ..., by_position, target) {
   if (!isTRUE(by_position)) {
     y_idx <- match(colnames(t1), colnames(t2))
     if (anyNA(y_idx)) {
-      abort("`by_position = FALSE` or `by_position = NULL` require column names in `x` to match those in `y`.")
+      cli::cli_abort(
+        "{.code by_position = FALSE} or {.code by_position = NULL} require column names in {.arg x} to match those in {.arg y}.",
+        call = dm_error_call()
+      )
     }
 
     t2 <-
