@@ -3,9 +3,16 @@
 #' @description If there are any permament tables on a DB, a new [`dm`] object can be created that contains those tables,
 #' along with their primary and foreign key constraints.
 #'
-#' Currently this only works with MSSQL and Postgres/Redshift databases.
+#' Currently this works for the following databases:
 #'
-#' The default database schema will be used; it is currently not possible to parametrize the funcion with a specific database schema.
+#' - Postgres/Redshift
+#' - MySQL/MariaDB
+#' - SQLite
+#' - MSSQL
+#' - DuckDB
+#'
+#' The default database schema is used if `schema` is `NULL`:
+#' `"dbo"` for MSSQL, `"public"` for Postgres/Redshift, and the current database for MariaDB/MySQL and for SQLite/DuckDB.
 #'
 #' @param dest A `src`-object on a DB or a connection to a DB.
 #'
@@ -33,7 +40,7 @@
 #'   iris_dm_learned <- dm_learn_from_db(src_sqlite)
 #' }
 #' @autoglobal
-dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{table}") {
+dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, names_pattern = "{.table}") {
   # assuming that we will not try to learn from (globally) temporary tables, which do not appear in sys.table
   con <- con_from_src_or_con(dest)
   src <- src_from_src_or_con(dest)
@@ -42,6 +49,8 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
     return()
   }
 
+  schema <- check_schema(con, schema)
+
   info <- dm_meta(con, catalog = dbname, schema = schema)
 
   df_info <-
@@ -51,8 +60,8 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
 
   dm_name <-
     df_info$tables %>%
-    select(catalog = table_catalog, schema = table_schema, table = table_name) %>%
-    mutate(name = glue(!!name_format)) %>%
+    select(catalog = table_catalog, .schema = table_schema, .table = table_name) %>%
+    mutate(name = glue(!!names_pattern)) %>%
     pull() %>%
     unclass() %>%
     vec_as_names(repair = "unique")
@@ -60,6 +69,8 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
   from <-
     df_info$tables %>%
     select(catalog = table_catalog, schema = table_schema, table = table_name) %>%
+    # RSQLite doesn't accept three-component identifiers, so we need to quote only the schema and table name
+    mutate(catalog = if (!all(is.na(catalog))) catalog) %>%
     pmap_chr(~ DBI::dbQuoteIdentifier(con, DBI::Id(...)))
 
   df_key_info <-
@@ -98,12 +109,21 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
     dm_update_zoomed() %>%
     dm_select_tbl(-table_constraints) %>%
     dm_flatten_to_tbl(key_column_usage, .recursive = TRUE) %>%
-    select(constraint_catalog, constraint_schema, constraint_name, dm_name, column_name, is_autoincrement) %>%
+    select(
+      constraint_catalog,
+      constraint_schema,
+      constraint_name,
+      dm_name,
+      column_name,
+      is_autoincrement
+    ) %>%
     group_by(constraint_catalog, constraint_schema, constraint_name, dm_name) %>%
-    summarize(pks = list(tibble(
-      column = list(column_name),
-      autoincrement = any(as.logical(is_autoincrement))
-    ))) %>%
+    summarize(
+      pks = list(tibble(
+        column = list(column_name),
+        autoincrement = any(as.logical(is_autoincrement))
+      ))
+    ) %>%
     ungroup() %>%
     select(table = dm_name, pks)
 
@@ -115,13 +135,19 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
     dm_zoom_to(key_column_usage) %>%
     semi_join(table_constraints) %>%
     left_join(table_constraints, select = c(delete_rule)) %>%
-    left_join(columns, select = c(column_name, dm_name, table_catalog, table_schema, table_name)) %>%
+    left_join(
+      columns,
+      select = c(column_name, dm_name, table_catalog, table_schema, table_name)
+    ) %>%
     dm_update_zoomed() %>%
     dm_select_tbl(-table_constraints) %>%
     dm_zoom_to(constraint_column_usage) %>%
     #
     # inner_join(): Matching column sometimes not found on Postgres
-    inner_join(columns, select = c(column_name, dm_name, table_catalog, table_schema, table_name)) %>%
+    inner_join(
+      columns,
+      select = c(column_name, dm_name, table_catalog, table_schema, table_name)
+    ) %>%
     #
     dm_update_zoomed() %>%
     dm_select_tbl(-columns) %>%
@@ -162,21 +188,24 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
       constraint_name,
       ref_table,
     ) %>%
-    summarize(fks = list(tibble(
-      ref_column = list(ref_column),
-      table = if (length(table) > 0) table[[1]] else NA_character_,
-      column = list(column),
-      on_delete = {
-        x <- case_when(
-          delete_rule == "CASCADE" ~ "cascade",
-          .default = "no_action"
-        ) %>% unique()
-        if (!is_empty(x) & !is_scalar_character(x)) {
-          abort("delete_rule for all fk_cols in one constraint_name should be the same")
+    summarize(
+      fks = list(tibble(
+        ref_column = list(ref_column),
+        table = if (length(table) > 0) table[[1]] else NA_character_,
+        column = list(column),
+        on_delete = {
+          x <- case_when(
+            delete_rule == "CASCADE" ~ "cascade",
+            .default = "no_action"
+          ) %>%
+            unique()
+          if (!is_empty(x) & !is_scalar_character(x)) {
+            cli::cli_abort("delete_rule for all fk_cols in one constraint_name should be the same.")
+          }
+          x
         }
-        x
-      }
-    ))) %>%
+      ))
+    ) %>%
     ungroup() %>%
     select(-(1:3)) %>%
     group_by(table = ref_table) %>%
@@ -191,7 +220,8 @@ dm_learn_from_db <- function(dest, dbname = NA, schema = NULL, name_format = "{t
 schema_if <- function(schema, table, con, dbname = NULL) {
   if (is_null(dbname) || is.na(dbname) || dbname == "") {
     purrr::map2(
-      schema, table,
+      schema,
+      table,
       ~ {
         if (is.na(.x)) {
           DBI::Id(table = .y)
@@ -203,9 +233,12 @@ schema_if <- function(schema, table, con, dbname = NULL) {
   } else {
     # 'schema_if()' only used internally (can e.g. be set to default schema beforehand)
     # so IMHO we don't need a formal 'dm_error' here
-    if (anyNA(schema)) abort("`schema` must be given if `dbname` is not NULL`.")
+    if (anyNA(schema)) {
+      cli::cli_abort("{.arg schema} must be given if {.arg dbname} is not {.code NULL}.")
+    }
     purrr::map2(
-      table, schema,
+      table,
+      schema,
       ~ DBI::Id(catalog = dbname, schema = .y, table = .x)
     )
   }
