@@ -4,7 +4,10 @@ rlang::on_load({
   if (rlang::is_installed("dbplyr") && getNamespaceInfo("dbplyr", "spec")["version"] <= "2.3.4") {
     dbplyr <- asNamespace("dbplyr")
     rlang::env_binding_unlock(dbplyr, "sql_values_subquery.MariaDBConnection")
-    try(dbplyr$sql_values_subquery.MariaDBConnection <- dbplyr$sql_values_subquery.DBIConnection, silent = TRUE)
+    try(
+      dbplyr$sql_values_subquery.MariaDBConnection <- dbplyr$sql_values_subquery.DBIConnection,
+      silent = TRUE
+    )
     rlang::env_binding_lock(dbplyr, "sql_values_subquery.MariaDBConnection")
   }
 })
