@@ -1,9 +1,11 @@
 new_ticker <- function(label, n, progress = NA, top_level_fun = NULL) {
-  suggested <- check_suggested("progress",
-    top_level_fun = top_level_fun,
-    use = progress
-  )
-  if (!suggested) return(identity)
+  stopifnot(is_bare_string(label))
+  stopifnot(is_bare_integerish(n, 1))
+
+  suggested <- check_suggested("progress", top_level_fun, use = progress)
+  if (!suggested) {
+    return(identity)
+  }
 
   # pb to be updated by reference by output function
   pb <- progress::progress_bar$new(
@@ -11,7 +13,8 @@ new_ticker <- function(label, n, progress = NA, top_level_fun = NULL) {
       "  %s [:bar] :percent in :elapsed",
       label
     ),
-    total = n, clear = FALSE
+    total = n,
+    clear = FALSE
   )
   # output a function that curries f to tick, updating pb
   function(f) {
