@@ -31,7 +31,14 @@
 #' dm_nycflights13() %>%
 #'   dm_draw()
 #' @autoglobal
-dm_nycflights13 <- function(..., cycle = FALSE, color = TRUE, subset = TRUE, compound = TRUE, table_description = FALSE) {
+dm_nycflights13 <- function(
+  ...,
+  cycle = FALSE,
+  color = TRUE,
+  subset = TRUE,
+  compound = TRUE,
+  table_description = FALSE
+) {
   check_dots_empty()
 
   if (subset) {
