@@ -39,8 +39,8 @@
 #'
 #' dm_nycflights13() %>%
 #'   dm_paste(options = "select")
-dm_paste <- function(dm, select = NULL, ..., tab_width = 2,
-                     options = NULL, path = NULL) {
+dm_paste <- function(dm, select = NULL, ..., tab_width = 2, options = NULL, path = NULL) {
+  dm_local_error_call()
   check_dots_empty(action = warn)
 
   options <- check_paste_options(options, select, caller_env())
@@ -71,7 +71,12 @@ check_paste_options <- function(options, select, env) {
   }
 
   if (!is.null(select)) {
-    deprecate_soft("0.1.2", "dm::dm_paste(select = )", "dm::dm_paste(options = 'select')", env = env)
+    deprecate_warn(
+      "0.1.2",
+      "dm::dm_paste(select = )",
+      "dm::dm_paste(options = 'select')",
+      env = env
+    )
     if (isTRUE(select)) {
       options <- c(options, "select")
     }
@@ -88,7 +93,7 @@ check_paste_options <- function(options, select, env) {
   options
 }
 
-dm_paste_impl <- function(dm, options, tab_width) {
+dm_paste_impl <- function(dm, options, tab_width, chunk_size = 100) {
   check_not_zoomed(dm)
   check_no_filter(dm)
 
@@ -115,17 +120,18 @@ dm_paste_impl <- function(dm, options, tab_width) {
   # adding code for color
   code_color <- if ("color" %in% options) dm_paste_color(dm)
 
-  # combine dm and paste code
-  code_dm <- glue_collapse(
-    c(
-      code_construct,
-      code_select,
-      code_pks,
-      code_uks,
-      code_fks,
-      code_color
-    ),
-    sep = glue(" %>%\n{tab}", .trim = FALSE)
+  # collect operations as named parts, preserving group boundaries for chunking
+  parts <- Filter(
+    function(x) length(x) > 0,
+    list(code_select, code_pks, code_uks, code_fks, code_color)
+  )
+
+  # combine dm construction and operations, chunking at group boundaries if needed
+  code_dm <- dm_paste_chunk_operations(
+    code_construct,
+    parts,
+    tab,
+    chunk_size = chunk_size
   )
 
   paste0(code_tables, code_dm)
@@ -173,7 +179,9 @@ dm_paste_pks <- function(dm) {
     mutate(
       code = if_else(
         !is.na(autoincrement) & autoincrement,
-        glue("dm::dm_add_pk({tick_if_needed(table)}, {deparse_keys(pk_col)}, autoincrement = TRUE)"),
+        glue(
+          "dm::dm_add_pk({tick_if_needed(table)}, {deparse_keys(pk_col)}, autoincrement = TRUE)"
+        ),
         glue("dm::dm_add_pk({tick_if_needed(table)}, {deparse_keys(pk_col)})")
       )
     ) %>%
@@ -203,7 +211,10 @@ dm_paste_fks <- function(dm) {
 
   need_non_default <- !map2_lgl(fpks$parent_key_cols, fpks$parent_default_pk_cols, identical)
   fpks$non_default_parent_key_cols <- ""
-  fpks$non_default_parent_key_cols[need_non_default] <- paste0(", ", deparse_keys(fpks$parent_key_cols[need_non_default]))
+  fpks$non_default_parent_key_cols[need_non_default] <- paste0(
+    ", ",
+    deparse_keys(fpks$parent_key_cols[need_non_default])
+  )
 
   on_delete <- if_else(
     fpks$on_delete != "no_action",
@@ -211,7 +222,9 @@ dm_paste_fks <- function(dm) {
     ""
   )
 
-  glue("dm::dm_add_fk({tick_if_needed(fpks$child_table)}, {deparse_keys(fpks$child_fk_cols)}, {tick_if_needed(fpks$parent_table)}{fpks$non_default_parent_key_cols}{on_delete})")
+  glue(
+    "dm::dm_add_fk({tick_if_needed(fpks$child_table)}, {deparse_keys(fpks$child_fk_cols)}, {tick_if_needed(fpks$parent_table)}{fpks$non_default_parent_key_cols}{on_delete})"
+  )
 }
 
 dm_paste_color <- function(dm) {
@@ -231,6 +244,80 @@ df_paste <- function(x, tab) {
   paste0("tibble::tibble(\n", cols, ")")
 }
 
+dm_paste_chunk_operations <- function(code_construct, parts, tab, chunk_size = 100) {
+  # Build chunks by accumulating complete groups (parts), never splitting a group
+  # across chunks unless the group itself exceeds chunk_size.
+  chunks_ops <- list()
+  current_ops <- character()
+
+  for (part in parts) {
+    if (length(current_ops) + length(part) <= chunk_size) {
+      # Entire part fits in the current chunk
+      current_ops <- c(current_ops, part)
+    } else {
+      # Part doesn't fit — flush the current chunk and handle the overflow
+      chunks_ops <- c(chunks_ops, list(current_ops))
+      current_ops <- character()
+      # Split the part into sub-chunks when it exceeds chunk_size on its own
+      sub_chunks <- split(part, ceiling(seq_along(part) / chunk_size))
+      for (j in seq_along(sub_chunks)) {
+        if (j < length(sub_chunks)) {
+          chunks_ops <- c(chunks_ops, list(sub_chunks[[j]]))
+        } else {
+          current_ops <- sub_chunks[[j]]
+        }
+      }
+    }
+  }
+  chunks_ops <- c(chunks_ops, list(current_ops))
+
+  # Remove a trailing empty chunk (can arise if the last part was exactly split
+  # into sub-chunks), but always keep at least one chunk for the construct.
+  if (length(chunks_ops) > 1 && length(chunks_ops[[length(chunks_ops)]]) == 0) {
+    chunks_ops <- chunks_ops[-length(chunks_ops)]
+  }
+
+  n_chunks <- length(chunks_ops)
+
+  # Single chunk: use a simple pipe chain with no intermediate variables
+  if (n_chunks == 1) {
+    return(glue_collapse(
+      c(code_construct, chunks_ops[[1]]),
+      sep = glue(" %>%\n{tab}", .trim = FALSE)
+    ))
+  }
+
+  # Multiple chunks: generate intermediate variable assignments
+  result_lines <- character()
+  for (i in seq_along(chunks_ops)) {
+    is_last <- i == n_chunks
+    var_name <- if (!is_last) paste0("dm_step_", i) else NULL
+    ops <- chunks_ops[[i]]
+
+    if (i == 1) {
+      chunk_code <- glue_collapse(
+        c(code_construct, ops),
+        sep = glue(" %>%\n{tab}", .trim = FALSE)
+      )
+    } else {
+      prev_var <- paste0("dm_step_", i - 1)
+      chunk_code <- paste0(
+        prev_var,
+        " %>%\n",
+        tab,
+        glue_collapse(ops, sep = glue(" %>%\n{tab}", .trim = FALSE))
+      )
+    }
+
+    result_lines <- c(
+      result_lines,
+      if (!is.null(var_name)) paste0(var_name, " <- ", chunk_code) else chunk_code
+    )
+  }
+
+  paste(result_lines, collapse = "\n\n")
+}
+
 deparse_line <- function(x) {
   attrs <- attributes(x)
   # Workaround necessary for R < 3.5:
@@ -260,10 +347,10 @@ dquote <- function(x) {
 # Errors ------------------------------------------------------------------
 
 abort_unknown_option <- function(options, all_options) {
-  abort(error_txt_unknown_option(options, all_options), class = dm_error_full("unknown_option"))
-}
-
-error_txt_unknown_option <- function(options, all_options) {
   bad_options <- setdiff(options, all_options)
-  glue("Option unknown: {commas(dquote(bad_options))}. Must be one of {commas(dquote(all_options))}.")
+  cli::cli_abort(
+    "{qty(length(bad_options))}Option{?s} unknown: {.val {bad_options}}. Must be one of {.val {all_options}}.",
+    class = dm_error_full("unknown_option"),
+    call = dm_error_call()
+  )
 }
