@@ -116,6 +116,7 @@ NULL
 #' @aliases dm_rows_...
 #' @export
 dm_rows_insert <- function(x, y, ..., in_place = NULL, progress = NA) {
+  dm_local_error_call()
   check_dots_empty()
 
   dm_rows(x, y, "insert", top_down = TRUE, in_place, require_keys = TRUE, progress = progress)
@@ -130,6 +131,7 @@ dm_rows_insert <- function(x, y, ..., in_place = NULL, progress = NA) {
 #' @rdname rows-dm
 #' @export
 dm_rows_append <- function(x, y, ..., in_place = NULL, progress = NA) {
+  dm_local_error_call()
   check_dots_empty()
 
   dm_rows(x, y, "append", top_down = TRUE, in_place, require_keys = FALSE, progress = progress)
@@ -143,6 +145,7 @@ dm_rows_append <- function(x, y, ..., in_place = NULL, progress = NA) {
 #' @rdname rows-dm
 #' @export
 dm_rows_update <- function(x, y, ..., in_place = NULL, progress = NA) {
+  dm_local_error_call()
   check_dots_empty()
 
   dm_rows(x, y, "update", top_down = TRUE, in_place, require_keys = TRUE, progress = progress)
@@ -157,6 +160,7 @@ dm_rows_update <- function(x, y, ..., in_place = NULL, progress = NA) {
 #' @rdname rows-dm
 #' @export
 dm_rows_patch <- function(x, y, ..., in_place = NULL, progress = NA) {
+  dm_local_error_call()
   check_dots_empty()
 
   dm_rows(x, y, "patch", top_down = TRUE, in_place, require_keys = TRUE, progress = progress)
@@ -170,6 +174,7 @@ dm_rows_patch <- function(x, y, ..., in_place = NULL, progress = NA) {
 #' @rdname rows-dm
 #' @export
 dm_rows_upsert <- function(x, y, ..., in_place = NULL, progress = NA) {
+  dm_local_error_call()
   check_dots_empty()
 
   dm_rows(x, y, "upsert", top_down = TRUE, in_place, require_keys = TRUE, progress = progress)
@@ -184,6 +189,7 @@ dm_rows_upsert <- function(x, y, ..., in_place = NULL, progress = NA) {
 #' @rdname rows-dm
 #' @export
 dm_rows_delete <- function(x, y, ..., in_place = NULL, progress = NA) {
+  dm_local_error_call()
   check_dots_empty()
 
   dm_rows(x, y, "delete", top_down = FALSE, in_place, require_keys = TRUE, progress = progress)
@@ -193,7 +199,9 @@ dm_rows <- function(x, y, operation_name, top_down, in_place, require_keys, prog
   dm_rows_check(x, y)
 
   if (is_null(in_place)) {
-    inform("Result is returned as a dm object with lazy tables. Use `in_place = FALSE` to mute this message, or `in_place = TRUE` to write to the underlying tables.")
+    cli::cli_inform(
+      "Result is returned as a dm object with lazy tables. Use {.code in_place = FALSE} to mute this message, or {.code in_place = TRUE} to write to the underlying tables."
+    )
     in_place <- FALSE
   }
 
@@ -237,13 +245,14 @@ check_keys_compatible <- function(x, y) {
 }
 
 get_dm_rows_op <- function(operation_name) {
-  switch(operation_name,
-    "insert"   = list(fun = do_rows_insert, pb_label = "inserting rows"),
-    "append"   = list(fun = do_rows_append, pb_label = "appending rows"),
-    "update"   = list(fun = do_rows_update, pb_label = "updating rows"),
-    "patch"    = list(fun = do_rows_patch, pb_label = "patching rows"),
-    "upsert"   = list(fun = do_rows_upsert, pb_label = "upserting rows"),
-    "delete"   = list(fun = do_rows_delete, pb_label = "deleting rows"),
+  switch(
+    operation_name,
+    "insert" = list(fun = do_rows_insert, pb_label = "inserting rows"),
+    "append" = list(fun = do_rows_append, pb_label = "appending rows"),
+    "update" = list(fun = do_rows_update, pb_label = "updating rows"),
+    "patch" = list(fun = do_rows_patch, pb_label = "patching rows"),
+    "upsert" = list(fun = do_rows_upsert, pb_label = "upserting rows"),
+    "delete" = list(fun = do_rows_delete, pb_label = "deleting rows"),
     "truncate" = list(fun = rows_truncate_, pb_label = "truncating rows")
   )
 }
@@ -273,7 +282,7 @@ do_rows_append <- function(x, y, by = NULL, ..., in_place = FALSE, autoinc_col =
     pull()
 
   if (anyDuplicated(key_values)) {
-    abort(paste0("Duplicate values for autoincrement primary key ", autoinc_col, "."))
+    cli::cli_abort("Duplicate values for autoincrement primary key {.field {autoinc_col}}.")
   }
 
   autoinc_col_new <- paste0(autoinc_col, "_new")
@@ -292,24 +301,30 @@ do_rows_append <- function(x, y, by = NULL, ..., in_place = FALSE, autoinc_col =
   old_interface <- identical(append_args, c("con", "x_name", "y", "...", "returning_cols"))
   if (old_interface) {
     target_name <- remote_name_qual(x)
-    insert_queries <- map(source_rows, ~ dbplyr::sql_query_append(
-      con,
-      target_name,
-      .x,
-      returning_cols = autoinc_col
-    ))
+    insert_queries <- map(
+      source_rows,
+      ~ dbplyr::sql_query_append(
+        con,
+        target_name,
+        .x,
+        returning_cols = autoinc_col
+      )
+    )
   } else {
     # FIXME: dbplyr::remote_table() private in dbplyr 2.3.3, public in dbplyr 2.4.0
     dbplyr_ns <- asNamespace("dbplyr")
     remote_table <- mget("remote_table", dbplyr_ns, mode = "function", ifnotfound = list(NULL))[[1]]
 
-    insert_queries <- map(source_rows, ~ dbplyr::sql_query_append(
-      con,
-      remote_table(x),
-      from = dbplyr::sql_render(.x, con),
-      insert_cols = colnames(.x),
-      returning_cols = autoinc_col
-    ))
+    insert_queries <- map(
+      source_rows,
+      ~ dbplyr::sql_query_append(
+        con,
+        remote_table(x),
+        from = dbplyr::sql_render(.x, con),
+        insert_cols = colnames(.x),
+        returning_cols = autoinc_col
+      )
+    )
   }
 
   autoinc_col_orig <- paste0(autoinc_col, "_orig")
@@ -349,10 +364,18 @@ do_rows_delete <- function(x, y, by = NULL, ..., autoinc_col = NULL) {
   rows_delete(x, y, by = by, ..., unmatched = "ignore")
 }
 
-dm_rows_run <- function(x, y, rows_op_name, top_down, in_place, require_keys, progress = NA) {
+dm_rows_run <- function(
+  x,
+  y,
+  rows_op_name,
+  top_down,
+  in_place,
+  require_keys,
+  progress = NA
+) {
   # topologically sort tables
   graph <- create_graph_from_dm(x, directed = TRUE)
-  topo <- igraph::topo_sort(graph, mode = if (top_down) "in" else "out")
+  topo <- graph_topo_sort(graph, mode = if (top_down) "in" else "out")
   tables <- intersect(names(topo), src_tbls_impl(y))
 
   # Use tables and keys
@@ -362,7 +385,10 @@ dm_rows_run <- function(x, y, rows_op_name, top_down, in_place, require_keys, pr
   if (require_keys) {
     all_pks <- dm_get_all_pks(x)
     if (!(all(tables %in% all_pks$table))) {
-      abort(glue("`dm_rows_{rows_op_name}()` requires the 'dm' object to have primary keys for all target tables."))
+      cli::cli_abort(
+        "{.fun dm_rows_{rows_op_name}} requires the {.cls dm} object to have primary keys for all target tables.",
+        call = dm_error_call()
+      )
     }
     keys <- all_pks$pk_col[match(tables, all_pks$table)]
   } else {
@@ -476,7 +502,6 @@ align_autoinc_fks <- function(tbls, target_dm, table, returning_rows) {
     align_tbl <- returning_rows
   }
 
-
   for (i in seq_along(fks_target$child_table)) {
     child_table <- fks_target$child_table[[i]]
     child_fk_col <- get_key_cols(fks_target$child_fk_cols[[i]])
@@ -533,7 +558,7 @@ rows_append_ai_local <- function(x, y, autoinc_col) {
 
 abort_columns_missing <- function(...) {
   # FIXME
-  abort("abort_columns_missing()")
+  cli::cli_abort("Column mismatch between target and source tables.", call = dm_error_call())
 }
 
 error_txt_columns_missing <- function(...) {
@@ -542,7 +567,7 @@ error_txt_columns_missing <- function(...) {
 
 abort_tables_missing <- function(...) {
   # FIXME
-  abort("abort_tables_missing()")
+  cli::cli_abort("Source tables are missing from target dm.", call = dm_error_call())
 }
 
 error_txt_tables_missing <- function(...) {
