@@ -54,7 +54,10 @@ is_this_a_test <- function() {
     map(1) %>%
     map_chr(as_label)
 
-  is_test_call <- any(calls %in% c("devtools::test", "testthat::test_check", "testthat::test_file", "testthis:::test_this"))
+  is_test_call <- any(
+    calls %in%
+      c("devtools::test", "testthat::test_check", "testthat::test_file", "testthis:::test_this")
+  )
 
   is_testing <- rlang::is_installed("testthat") && testthat::is_testing()
 
@@ -64,8 +67,11 @@ is_this_a_test <- function() {
 
 # more general 'check'-type functions -------------------------------------
 
-
-check_param_class <- function(param_value, correct_class, param_name = deparse(substitute(param_value))) {
+check_param_class <- function(
+  param_value,
+  correct_class,
+  param_name = deparse(substitute(param_value))
+) {
   if (!inherits(param_value, correct_class)) {
     abort_parameter_not_correct_class(
       parameter = param_name,
@@ -75,7 +81,11 @@ check_param_class <- function(param_value, correct_class, param_name = deparse(s
   }
 }
 
-check_param_length <- function(param_value, correct_length = 1, param_name = deparse(substitute(param_value))) {
+check_param_length <- function(
+  param_value,
+  correct_length = 1,
+  param_name = deparse(substitute(param_value))
+) {
   if (length(param_value) != correct_length) {
     abort_parameter_not_correct_length(
       parameter = param_name,
@@ -88,17 +98,17 @@ check_param_length <- function(param_value, correct_length = 1, param_name = dep
 # general error: table not part of `dm` -----------------------------------
 
 abort_table_missing <- function(arg_name) {
-  abort(error_txt_table_missing(arg_name), class = dm_error_full("table_missing"))
-}
-
-error_txt_table_missing <- function(arg_name) {
-  glue("Must pass {tick(arg_name)} argument.")
+  cli::cli_abort(
+    "Must pass {.arg {arg_name}} argument.",
+    class = dm_error_full("table_missing"),
+    call = dm_error_call()
+  )
 }
 
 abort_table_not_in_dm <- function(table_name, dm_tables) {
-  abort(error_txt_table_not_in_dm(table_name, dm_tables), class = dm_error_full("table_not_in_dm"))
-}
-
-error_txt_table_not_in_dm <- function(table_name, dm_tables) {
-  glue("Table {commas(tick(table_name))} not in `dm` object. Available table names: {commas(tick(dm_tables))}.")
+  cli::cli_abort(
+    "Table {.field {table_name}} not in {.cls dm} object. Available table names: {.field {dm_tables}}.",
+    class = dm_error_full("table_not_in_dm"),
+    call = dm_error_call()
+  )
 }
