@@ -1,5 +1,4 @@
-expect_error_obj <- function(object, regexp = NULL, class = NULL, ...,
-                             info = NULL, label = NULL) {
+expect_error_obj <- function(object, regexp = NULL, class = NULL, ..., info = NULL, label = NULL) {
   testthat::expect_error(
     obj <- rlang::eval_tidy({{ object }}),
     regexp = regexp,
@@ -12,8 +11,14 @@ expect_error_obj <- function(object, regexp = NULL, class = NULL, ...,
   invisible(obj)
 }
 
-expect_warning_obj <- function(object, regexp = NULL, class = NULL, ...,
-                               info = NULL, label = NULL) {
+expect_warning_obj <- function(
+  object,
+  regexp = NULL,
+  class = NULL,
+  ...,
+  info = NULL,
+  label = NULL
+) {
   testthat::expect_warning(
     obj <- rlang::eval_tidy({{ object }}),
     regexp = regexp,
@@ -25,8 +30,14 @@ expect_warning_obj <- function(object, regexp = NULL, class = NULL, ...,
   invisible(obj)
 }
 
-expect_message_obj <- function(object, regexp = NULL, class = NULL, ...,
-                               info = NULL, label = NULL) {
+expect_message_obj <- function(
+  object,
+  regexp = NULL,
+  class = NULL,
+  ...,
+  info = NULL,
+  label = NULL
+) {
   testthat::expect_message(
     obj <- rlang::eval_tidy({{ object }}),
     regexp = regexp,
@@ -38,8 +49,14 @@ expect_message_obj <- function(object, regexp = NULL, class = NULL, ...,
   invisible(obj)
 }
 
-expect_condition_obj <- function(object, regexp = NULL, class = NULL, ...,
-                                 info = NULL, label = NULL) {
+expect_condition_obj <- function(
+  object,
+  regexp = NULL,
+  class = NULL,
+  ...,
+  info = NULL,
+  label = NULL
+) {
   testthat::expect_condition(
     obj <- rlang::eval_tidy({{ object }}),
     regexp = regexp,
@@ -51,8 +68,7 @@ expect_condition_obj <- function(object, regexp = NULL, class = NULL, ...,
   invisible(obj)
 }
 
-expect_deprecated_obj <- function(object, regexp = NULL, ...,
-                                  info = NULL, label = NULL) {
+expect_deprecated_obj <- function(object, regexp = NULL, ..., info = NULL, label = NULL) {
   lifecycle::expect_deprecated(
     obj <- rlang::eval_tidy({{ object }}),
     regexp = regexp,
