@@ -10,11 +10,17 @@ dm_upgrade <- function(dm, quiet) {
       message("Upgrading dm object created with dm <= 0.2.1.")
     }
     def <- unclass(dm)$def
-    def$fks <- list_of(!!!map2(def$fks, def$pks, ~ {
-      .x[["ref_column"]] <- .y[["column"]]
-      .x <- .x[c("ref_column", "table", "column")]
-      .x
-    }))
+    def$fks <- list_of(
+      !!!map2(
+        def$fks,
+        def$pks,
+        ~ {
+          .x[["ref_column"]] <- .y[["column"]]
+          .x <- .x[c("ref_column", "table", "column")]
+          .x
+        }
+      )
+    )
     dm <- dm_from_def(def, zoomed = is_zoomed(dm), validate = FALSE)
   }
 
