@@ -2,7 +2,7 @@
 #' @keywords internal
 #' @export
 check_if_subset <- function(t1, c1, t2, c2) {
-  deprecate_soft("0.1.0", "dm::check_if_subset()", "dm::check_subset()")
+  deprecate_warn("0.1.0", "dm::check_if_subset()", "dm::check_subset()")
   t1q <- enquo(t1)
   t2q <- enquo(t2)
   c1q <- ensym(c1)
@@ -15,7 +15,9 @@ check_if_subset <- function(t1, c1, t2, c2) {
   setdiff_v1_v2 <- setdiff(v1, v2)
   print(filter(eval_tidy(t1q), !!c1q %in% setdiff_v1_v2))
   abort_not_subset_of(
-    as_name(t1q), as_name(c1q), as_name(t2q),
+    as_name(t1q),
+    as_name(c1q),
+    as_name(t2q),
     as_name(c2q)
   )
 }
@@ -24,7 +26,7 @@ check_if_subset <- function(t1, c1, t2, c2) {
 #' @keywords internal
 #' @export
 check_cardinality <- function(parent_table, pk_column, child_table, fk_column) {
-  deprecate_soft("0.1.0", "dm::check_cardinality()", "dm::examine_cardinality()")
+  deprecate_warn("0.1.0", "dm::check_cardinality()", "dm::examine_cardinality()")
   pt <- enquo(parent_table)
   pkc <- enexpr(pk_column)
   ct <- enquo(child_table)
@@ -57,7 +59,7 @@ check_cardinality <- function(parent_table, pk_column, child_table, fk_column) {
 #' @keywords internal
 #' @export
 cdm_get_src <- function(x) {
-  deprecate_soft("0.1.0", "dm::cdm_get_src()", "dm::dm_get_con()")
+  deprecate_warn("0.1.0", "dm::cdm_get_src()", "dm::dm_get_con()")
   check_not_zoomed(x)
   out <- dm_get_src_impl(x)
   if (is.null(out)) {
@@ -77,7 +79,7 @@ default_local_src <- function() {
 #' @keywords internal
 #' @export
 cdm_get_con <- function(x) {
-  deprecate_soft("0.1.0", "dm::cdm_get_con()", "dm::dm_get_con()")
+  deprecate_warn("0.1.0", "dm::cdm_get_con()", "dm::dm_get_con()")
   dm_get_con(dm = x)
 }
 
@@ -85,7 +87,7 @@ cdm_get_con <- function(x) {
 #' @keywords internal
 #' @export
 cdm_get_tables <- function(x) {
-  deprecate_soft("0.1.0", "dm::cdm_get_tables()", "dm::dm_get_tables()")
+  deprecate_warn("0.1.0", "dm::cdm_get_tables()", "dm::dm_get_tables()")
   dm_get_tables(x = x)
 }
 
@@ -93,7 +95,7 @@ cdm_get_tables <- function(x) {
 #' @keywords internal
 #' @export
 cdm_get_filter <- function(x) {
-  deprecate_soft("0.1.0", "dm::cdm_get_filter()", "dm::dm_get_filters()")
+  deprecate_warn("0.1.0", "dm::cdm_get_filter()", "dm::dm_get_filters()")
   dm_get_filters(dm = x)
 }
 
@@ -101,7 +103,7 @@ cdm_get_filter <- function(x) {
 #' @keywords internal
 #' @export
 cdm_add_tbl <- function(dm, ..., repair = "unique", quiet = FALSE) {
-  deprecate_soft("0.1.0", "dm::cdm_add_tbl()", "dm::dm_add_tbl()")
+  deprecate_warn("0.1.0", "dm::cdm_add_tbl()", "dm::dm_add_tbl()")
   dm_add_tbl(dm = dm, ... = ..., repair = repair, quiet = quiet)
 }
 
@@ -109,17 +111,27 @@ cdm_add_tbl <- function(dm, ..., repair = "unique", quiet = FALSE) {
 #' @keywords internal
 #' @export
 cdm_rm_tbl <- function(dm, ...) {
-  deprecate_soft("0.1.0", "dm::cdm_rm_tbl()", "dm::dm_select_tbl()")
+  deprecate_warn("0.1.0", "dm::cdm_rm_tbl()", "dm::dm_select_tbl()")
   dm_rm_tbl_impl(dm = dm, ... = ...)
 }
 
 #' @rdname deprecated
 #' @keywords internal
 #' @export
-cdm_copy_to <- function(dest, dm, ..., types = NULL, overwrite = NULL, indexes = NULL,
-                        unique_indexes = NULL, set_key_constraints = TRUE, unique_table_names = FALSE,
-                        table_names = NULL, temporary = TRUE) {
-  deprecate_soft("0.1.0", "dm::cdm_copy_to()", "dm::copy_dm_to()")
+cdm_copy_to <- function(
+  dest,
+  dm,
+  ...,
+  types = NULL,
+  overwrite = NULL,
+  indexes = NULL,
+  unique_indexes = NULL,
+  set_key_constraints = TRUE,
+  unique_table_names = FALSE,
+  table_names = NULL,
+  temporary = TRUE
+) {
+  deprecate_warn("0.1.0", "dm::cdm_copy_to()", "dm::copy_dm_to()")
 
   if (!is_null(unique_table_names)) {
     if (is.null(table_names) && temporary && !unique_table_names) {
@@ -147,21 +159,36 @@ cdm_copy_to <- function(dest, dm, ..., types = NULL, overwrite = NULL, indexes =
 #' @keywords internal
 #' @export
 cdm_disambiguate_cols <- function(dm, sep = ".", quiet = FALSE) {
-  deprecate_soft("0.1.0", "dm::cdm_disambiguate_cols()", "dm::dm_disambiguate_cols()")
+  deprecate_warn("0.1.0", "dm::cdm_disambiguate_cols()", "dm::dm_disambiguate_cols()")
   dm_disambiguate_cols(dm = dm, .sep = sep, .quiet = quiet)
 }
 
 #' @rdname deprecated
 #' @keywords internal
 #' @export
-cdm_draw <- function(dm, rankdir = "LR", col_attr = "column", view_type = "keys_only",
-                     columnArrows = TRUE, graph_attrs = "", node_attrs = "", edge_attrs = "",
-                     focus = NULL, graph_name = "Data Model") {
-  deprecate_soft("0.1.0", "dm::cdm_draw()", "dm::dm_draw()")
+cdm_draw <- function(
+  dm,
+  rankdir = "LR",
+  col_attr = "column",
+  view_type = "keys_only",
+  columnArrows = TRUE,
+  graph_attrs = "",
+  node_attrs = "",
+  edge_attrs = "",
+  focus = NULL,
+  graph_name = "Data Model"
+) {
+  deprecate_warn("0.1.0", "dm::cdm_draw()", "dm::dm_draw()")
   dm_draw(
-    dm = dm, rankdir = rankdir, col_attr = col_attr,
-    view_type = view_type, columnArrows = columnArrows, graph_attrs = graph_attrs,
-    node_attrs = node_attrs, edge_attrs = edge_attrs, focus = focus,
+    dm = dm,
+    rankdir = rankdir,
+    col_attr = col_attr,
+    view_type = view_type,
+    columnArrows = columnArrows,
+    graph_attrs = graph_attrs,
+    node_attrs = node_attrs,
+    edge_attrs = edge_attrs,
+    focus = focus,
     graph_name = graph_name
   )
 }
@@ -170,7 +197,7 @@ cdm_draw <- function(dm, rankdir = "LR", col_attr = "column", view_type = "keys_
 #' @keywords internal
 #' @export
 cdm_set_colors <- function(dm, ...) {
-  deprecate_soft("0.1.0", "dm::cdm_set_colors()", "dm::dm_set_colors()")
+  deprecate_warn("0.1.0", "dm::cdm_set_colors()", "dm::dm_set_colors()")
   display <- color_quos_to_display(...)
   dm_set_colors(dm, !!!display)
 }
@@ -179,7 +206,7 @@ cdm_set_colors <- function(dm, ...) {
 #' @keywords internal
 #' @export
 cdm_get_colors <- function(dm) {
-  deprecate_soft("0.1.0", "dm::cdm_get_colors()", "dm::dm_get_colors()")
+  deprecate_warn("0.1.0", "dm::cdm_get_colors()", "dm::dm_get_colors()")
   prep_recode(dm_get_colors(dm))
 }
 
@@ -187,8 +214,9 @@ cdm_get_colors <- function(dm) {
 #' @keywords internal
 #' @export
 cdm_get_available_colors <- function() {
-  deprecate_soft(
-    "0.1.0", "dm::cdm_get_available_colors()",
+  deprecate_warn(
+    "0.1.0",
+    "dm::cdm_get_available_colors()",
     "dm::dm_get_available_colors()"
   )
   dm_get_available_colors()
@@ -198,7 +226,7 @@ cdm_get_available_colors <- function() {
 #' @keywords internal
 #' @export
 cdm_filter <- function(dm, table, ...) {
-  deprecate_soft("0.1.0", "dm::cdm_filter()", "dm::dm_filter()")
+  deprecate_warn("0.1.0", "dm::cdm_filter()", "dm::dm_filter()")
   dm %>%
     dm_zoom_to({{ table }}) %>%
     dm_filter_impl(..., set_filter = TRUE) %>%
@@ -209,7 +237,7 @@ cdm_filter <- function(dm, table, ...) {
 #' @keywords internal
 #' @export
 cdm_nrow <- function(dm) {
-  deprecate_soft("0.1.0", "dm::cdm_nrow()", "dm::dm_nrow()")
+  deprecate_warn("0.1.0", "dm::cdm_nrow()", "dm::dm_nrow()")
   dm_nrow(dm = dm)
 }
 
@@ -217,29 +245,47 @@ cdm_nrow <- function(dm) {
 #' @keywords internal
 #' @export
 cdm_flatten_to_tbl <- function(dm, start, ..., join = left_join) {
-  deprecate_soft("0.1.0", "dm::cdm_flatten_to_tbl()", "dm::dm_flatten_to_tbl()")
+  deprecate_warn("0.1.0", "dm::cdm_flatten_to_tbl()", "dm::dm_flatten_to_tbl()")
   join_name <- deparse(substitute(join))
   start <- dm_tbl_name(dm, {{ start }})
 
   vars <- setdiff(src_tbls_impl(dm), start)
   list_of_pts <- eval_select_table(quo(c(...)), vars)
 
-  dm_flatten_to_tbl_impl(dm, start, list_of_pts, join = join, join_name = join_name, squash = FALSE, .position = "prefix")
+  dm_flatten_to_tbl_impl(
+    dm,
+    start,
+    list_of_pts,
+    join = join,
+    join_name = join_name,
+    squash = FALSE,
+    .position = "prefix"
+  )
 }
 
 #' @rdname deprecated
 #' @keywords internal
 #' @export
 cdm_squash_to_tbl <- function(dm, start, ..., join = left_join) {
-  deprecate_soft("0.1.0", "dm::cdm_squash_to_tbl()", "dm::dm_squash_to_tbl()")
+  deprecate_warn("0.1.0", "dm::cdm_squash_to_tbl()", "dm::dm_squash_to_tbl()")
   join_name <- deparse(substitute(join))
-  if (!(join_name %in% c("left_join", "full_join", "inner_join"))) abort_squash_limited()
+  if (!(join_name %in% c("left_join", "full_join", "inner_join"))) {
+    abort_squash_limited()
+  }
   start <- dm_tbl_name(dm, {{ start }})
 
   vars <- setdiff(src_tbls_impl(dm), start)
   list_of_pts <- eval_select_table(quo(c(...)), vars)
 
-  dm_flatten_to_tbl_impl(dm, start, list_of_pts, join = join, join_name = join_name, squash = TRUE, .position = "prefix")
+  dm_flatten_to_tbl_impl(
+    dm,
+    start,
+    list_of_pts,
+    join = join,
+    join_name = join_name,
+    squash = TRUE,
+    .position = "prefix"
+  )
 }
 
 #' @rdname deprecated
@@ -247,7 +293,7 @@ cdm_squash_to_tbl <- function(dm, start, ..., join = left_join) {
 #' @export
 cdm_join_to_tbl <- function(dm, table_1, table_2, join = left_join) {
   force(join)
-  deprecate_soft("0.1.0", "dm::cdm_join_to_tbl()", "dm::dm_join_to_tbl()")
+  deprecate_warn("0.1.0", "dm::cdm_join_to_tbl()", "dm::dm_join_to_tbl()")
   stopifnot(is_function(join))
   join_name <- deparse(substitute(join))
 
@@ -258,14 +304,22 @@ cdm_join_to_tbl <- function(dm, table_1, table_2, join = left_join) {
   start <- rel$child_table
   other <- rel$parent_table
 
-  dm_flatten_to_tbl_impl(dm, start, other, join = join, join_name = join_name, squash = FALSE, .position = "prefix")
+  dm_flatten_to_tbl_impl(
+    dm,
+    start,
+    other,
+    join = join,
+    join_name = join_name,
+    squash = FALSE,
+    .position = "prefix"
+  )
 }
 
 #' @rdname deprecated
 #' @keywords internal
 #' @export
 cdm_apply_filters <- function(dm) {
-  deprecate_soft("0.1.0", "dm::cdm_apply_filters()", "dm::dm_apply_filters()")
+  deprecate_warn("0.1.0", "dm::cdm_apply_filters()", "dm::dm_apply_filters()")
   dm_apply_filters(dm = dm)
 }
 
@@ -273,8 +327,9 @@ cdm_apply_filters <- function(dm) {
 #' @keywords internal
 #' @export
 cdm_apply_filters_to_tbl <- function(dm, table) {
-  deprecate_soft(
-    "0.1.0", "dm::cdm_apply_filters_to_tbl()",
+  deprecate_warn(
+    "0.1.0",
+    "dm::cdm_apply_filters_to_tbl()",
     "dm::dm_apply_filters_to_tbl()"
   )
   check_not_zoomed(dm)
@@ -286,7 +341,7 @@ cdm_apply_filters_to_tbl <- function(dm, table) {
 #' @keywords internal
 #' @export
 cdm_add_pk <- function(dm, table, column, check = FALSE, force = FALSE) {
-  deprecate_soft("0.1.0", "dm::cdm_add_pk()", "dm::dm_add_pk()")
+  deprecate_warn("0.1.0", "dm::cdm_add_pk()", "dm::dm_add_pk()")
   dm_add_pk(dm, {{ table }}, {{ column }}, check = check, force = force)
 }
 
@@ -294,7 +349,7 @@ cdm_add_pk <- function(dm, table, column, check = FALSE, force = FALSE) {
 #' @keywords internal
 #' @export
 cdm_add_fk <- function(dm, table, column, ref_table, check = FALSE) {
-  deprecate_soft("0.1.0", "dm::cdm_add_fk()", "dm::dm_add_fk()")
+  deprecate_warn("0.1.0", "dm::cdm_add_fk()", "dm::dm_add_fk()")
   dm_add_fk(dm, {{ table }}, {{ column }}, {{ ref_table }}, check = check)
 }
 
@@ -302,7 +357,7 @@ cdm_add_fk <- function(dm, table, column, ref_table, check = FALSE) {
 #' @keywords internal
 #' @export
 cdm_has_fk <- function(dm, table, ref_table) {
-  deprecate_soft("0.1.0", "dm::cdm_has_fk()", "dm::dm_has_fk()")
+  deprecate_warn("0.1.0", "dm::cdm_has_fk()", "dm::dm_has_fk()")
   check_not_zoomed(dm)
   table_name <- dm_tbl_name(dm, {{ table }})
   ref_table_name <- dm_tbl_name(dm, {{ ref_table }})
@@ -313,7 +368,7 @@ cdm_has_fk <- function(dm, table, ref_table) {
 #' @keywords internal
 #' @export
 cdm_get_fk <- function(dm, table, ref_table) {
-  deprecate_soft("0.1.0", "dm::cdm_get_fk()", "dm::dm_get_fk()")
+  deprecate_warn("0.1.0", "dm::cdm_get_fk()", "dm::dm_get_fk()")
   check_not_zoomed(dm)
   table_name <- dm_tbl_name(dm, {{ table }})
   ref_table_name <- dm_tbl_name(dm, {{ ref_table }})
@@ -324,7 +379,7 @@ cdm_get_fk <- function(dm, table, ref_table) {
 #' @keywords internal
 #' @export
 cdm_get_all_fks <- function(dm) {
-  deprecate_soft("0.1.0", "dm::cdm_get_all_fks()", "dm::dm_get_all_fks()")
+  deprecate_warn("0.1.0", "dm::cdm_get_all_fks()", "dm::dm_get_all_fks()")
   dm %>%
     dm_get_all_fks_impl() %>%
     mutate(child_fk_cols = as.character(unclass(child_fk_cols))) %>%
@@ -335,7 +390,7 @@ cdm_get_all_fks <- function(dm) {
 #' @keywords internal
 #' @export
 cdm_rm_fk <- function(dm, table, columns, ref_table) {
-  deprecate_soft("0.1.0", "dm::cdm_rm_fk()", "dm::dm_rm_fk()")
+  deprecate_warn("0.1.0", "dm::cdm_rm_fk()", "dm::dm_rm_fk()")
   check_not_zoomed(dm)
   column_quo <- enquo(columns)
   if (quo_is_missing(column_quo)) {
@@ -363,7 +418,7 @@ cdm_rm_fk <- function(dm, table, columns, ref_table) {
 #' @export
 #' @autoglobal
 cdm_enum_fk_candidates <- function(dm, table, ref_table) {
-  deprecate_soft("0.1.0", "dm::cdm_enum_fk_candidates()", "dm::dm_enum_fk_candidates()")
+  deprecate_warn("0.1.0", "dm::cdm_enum_fk_candidates()", "dm::dm_enum_fk_candidates()")
   check_not_zoomed(dm)
   check_no_filter(dm)
   table_name <- dm_tbl_name(dm, {{ table }})
@@ -373,8 +428,11 @@ cdm_enum_fk_candidates <- function(dm, table, ref_table) {
   ref_tbl <- tbl_impl(dm, ref_table_name)
   tbl <- tbl_impl(dm, table_name)
   enum_fk_candidates_impl(
-    table_name, tbl, ref_table_name,
-    ref_tbl, ref_tbl_pk
+    table_name,
+    tbl,
+    ref_table_name,
+    ref_tbl,
+    ref_tbl_pk
   ) %>%
     rename(columns = column) %>%
     mutate(columns = new_keys(columns))
@@ -384,7 +442,7 @@ cdm_enum_fk_candidates <- function(dm, table, ref_table) {
 #' @keywords internal
 #' @export
 cdm_is_referenced <- function(dm, table) {
-  deprecate_soft("0.1.0", "dm::cdm_is_referenced()", "dm::dm_is_referenced()")
+  deprecate_warn("0.1.0", "dm::cdm_is_referenced()", "dm::dm_is_referenced()")
   check_not_zoomed(dm)
   has_length(dm_get_referencing_tables(dm, !!ensym(table)))
 }
@@ -393,8 +451,9 @@ cdm_is_referenced <- function(dm, table) {
 #' @keywords internal
 #' @export
 cdm_get_referencing_tables <- function(dm, table) {
-  deprecate_soft(
-    "0.1.0", "dm::cdm_get_referencing_tables()",
+  deprecate_warn(
+    "0.1.0",
+    "dm::cdm_get_referencing_tables()",
     "dm::dm_get_referencing_tables()"
   )
   check_not_zoomed(dm)
@@ -408,7 +467,7 @@ cdm_get_referencing_tables <- function(dm, table) {
 #' @keywords internal
 #' @export
 cdm_learn_from_db <- function(dest) {
-  deprecate_soft("0.1.0", "dm::cdm_learn_from_db()", "dm::dm_from_src()")
+  deprecate_warn("0.1.0", "dm::cdm_learn_from_db()", "dm::dm_from_src()")
   dm_from_con(con_from_src_or_con(dest))
 }
 
@@ -416,7 +475,7 @@ cdm_learn_from_db <- function(dest) {
 #' @keywords internal
 #' @export
 cdm_check_constraints <- function(dm) {
-  deprecate_soft("0.1.0", "dm::cdm_check_constraints()", "dm::dm_examine_constraints()")
+  deprecate_warn("0.1.0", "dm::cdm_check_constraints()", "dm::dm_examine_constraints()")
   dm_examine_constraints_impl(dm = dm, progress = FALSE, top_level_fun = "cdm_check_constraints")
 }
 
@@ -424,7 +483,7 @@ cdm_check_constraints <- function(dm) {
 #' @keywords internal
 #' @export
 cdm_nycflights13 <- function(cycle = FALSE, color = TRUE, subset = TRUE) {
-  deprecate_soft("0.1.0", "dm::cdm_nycflights13()", "dm::dm_nycflights13()")
+  deprecate_warn("0.1.0", "dm::cdm_nycflights13()", "dm::dm_nycflights13()")
   dm_nycflights13(cycle = cycle, color = color, subset = subset)
 }
 
@@ -432,7 +491,7 @@ cdm_nycflights13 <- function(cycle = FALSE, color = TRUE, subset = TRUE) {
 #' @keywords internal
 #' @export
 cdm_paste <- function(dm, select = FALSE, tab_width = 2) {
-  deprecate_soft("0.1.0", "dm::cdm_paste()", "dm::dm_paste()")
+  deprecate_warn("0.1.0", "dm::cdm_paste()", "dm::dm_paste()")
 
   if (isTRUE(select)) {
     options <- c("keys", "select")
@@ -452,7 +511,7 @@ cdm_paste <- function(dm, select = FALSE, tab_width = 2) {
 #' @keywords internal
 #' @export
 cdm_has_pk <- function(dm, table) {
-  deprecate_soft("0.1.0", "dm::cdm_has_pk()", "dm::dm_has_pk()")
+  deprecate_warn("0.1.0", "dm::cdm_has_pk()", "dm::dm_has_pk()")
   check_not_zoomed(dm)
   has_length(dm_get_pk(dm, {{ table }}))
 }
@@ -461,7 +520,7 @@ cdm_has_pk <- function(dm, table) {
 #' @keywords internal
 #' @export
 cdm_get_pk <- function(dm, table) {
-  deprecate_soft("0.1.0", "dm::cdm_get_pk()", "dm::dm_get_pk()")
+  deprecate_warn("0.1.0", "dm::cdm_get_pk()", "dm::dm_get_pk()")
   check_not_zoomed(dm)
   table_name <- dm_tbl_name(dm, {{ table }})
   new_keys(dm_get_pk_impl(dm, table_name))
@@ -471,7 +530,7 @@ cdm_get_pk <- function(dm, table) {
 #' @keywords internal
 #' @export
 cdm_get_all_pks <- function(dm) {
-  deprecate_soft("0.1.0", "dm::cdm_get_all_pks()", "dm::dm_get_all_pks()")
+  deprecate_warn("0.1.0", "dm::cdm_get_all_pks()", "dm::dm_get_all_pks()")
   dm %>%
     dm_get_all_pks_impl() %>%
     mutate(pk_col = as.character(unclass(pk_col)))
@@ -481,7 +540,7 @@ cdm_get_all_pks <- function(dm) {
 #' @keywords internal
 #' @export
 cdm_rm_pk <- function(dm, table, rm_referencing_fks = FALSE) {
-  deprecate_soft("0.1.0", "dm::cdm_rm_pk()", "dm::dm_rm_pk()")
+  deprecate_warn("0.1.0", "dm::cdm_rm_pk()", "dm::dm_rm_pk()")
   check_not_zoomed(dm)
   table_name <- dm_tbl_name(dm, {{ table }})
   def <- dm_get_def(dm)
@@ -498,7 +557,7 @@ cdm_rm_pk <- function(dm, table, rm_referencing_fks = FALSE) {
 #' @keywords internal
 #' @export
 cdm_enum_pk_candidates <- function(dm, table) {
-  deprecate_soft("0.1.0", "dm::cdm_enum_pk_candidates()", "dm::dm_enum_pk_candidates()")
+  deprecate_warn("0.1.0", "dm::cdm_enum_pk_candidates()", "dm::dm_enum_pk_candidates()")
   check_no_filter(dm)
 
   table_name <- dm_tbl_name(dm, {{ table }})
@@ -511,7 +570,7 @@ cdm_enum_pk_candidates <- function(dm, table) {
 #' @keywords internal
 #' @export
 cdm_select_tbl <- function(dm, ...) {
-  deprecate_soft("0.1.0", "dm::cdm_select_tbl()", "dm::dm_select_tbl()")
+  deprecate_warn("0.1.0", "dm::cdm_select_tbl()", "dm::dm_select_tbl()")
   dm_select_tbl(dm = dm, ... = ...)
 }
 
@@ -519,7 +578,7 @@ cdm_select_tbl <- function(dm, ...) {
 #' @keywords internal
 #' @export
 cdm_rename_tbl <- function(dm, ...) {
-  deprecate_soft("0.1.0", "dm::cdm_rename_tbl()", "dm::dm_rename_tbl()")
+  deprecate_warn("0.1.0", "dm::cdm_rename_tbl()", "dm::dm_rename_tbl()")
   dm_rename_tbl(dm = dm, ... = ...)
 }
 
@@ -527,7 +586,7 @@ cdm_rename_tbl <- function(dm, ...) {
 #' @keywords internal
 #' @export
 cdm_select <- function(dm, table, ...) {
-  deprecate_soft("0.1.0", "dm::cdm_select()", "dm::dm_select()")
+  deprecate_warn("0.1.0", "dm::cdm_select()", "dm::dm_select()")
   check_not_zoomed(dm)
   table_name <- dm_tbl_name(dm, {{ table }})
 
@@ -541,7 +600,7 @@ cdm_select <- function(dm, table, ...) {
 #' @keywords internal
 #' @export
 cdm_rename <- function(dm, table, ...) {
-  deprecate_soft("0.1.0", "dm::cdm_rename()", "dm::dm_rename()")
+  deprecate_warn("0.1.0", "dm::cdm_rename()", "dm::dm_rename()")
   check_not_zoomed(dm)
   table_name <- dm_tbl_name(dm, {{ table }})
 
@@ -555,7 +614,7 @@ cdm_rename <- function(dm, table, ...) {
 #' @keywords internal
 #' @export
 cdm_zoom_to_tbl <- function(dm, table) {
-  deprecate_soft("0.1.0", "dm::cdm_zoom_to_tbl()", "dm::dm_zoom_to()")
+  deprecate_warn("0.1.0", "dm::cdm_zoom_to_tbl()", "dm::dm_zoom_to()")
   check_not_zoomed(dm)
   zoom <- dm_tbl_name(dm, {{ table }})
 
@@ -573,7 +632,7 @@ cdm_zoom_to_tbl <- function(dm, table) {
 #' @keywords internal
 #' @export
 cdm_insert_zoomed_tbl <- function(dm, new_tbl_name = NULL, repair = "unique", quiet = FALSE) {
-  deprecate_soft("0.1.0", "dm::cdm_insert_zoomed_tbl()", "dm::dm_insert_zoomed()")
+  deprecate_warn("0.1.0", "dm::cdm_insert_zoomed_tbl()", "dm::dm_insert_zoomed()")
 
   check_zoomed(dm)
   if (is_null(enexpr(new_tbl_name))) {
@@ -586,7 +645,9 @@ cdm_insert_zoomed_tbl <- function(dm, new_tbl_name = NULL, repair = "unique", qu
   }
   names_list <- repair_table_names(
     old_names = src_tbls_impl(dm),
-    new_names = new_tbl_name_chr, repair, quiet
+    new_names = new_tbl_name_chr,
+    repair,
+    quiet
   )
   dm <- dm_select_tbl_zoomed_impl(dm, names_list$new_old_names)
   new_tbl_name_chr <- names_list$new_names
@@ -612,12 +673,18 @@ cdm_insert_zoomed_tbl <- function(dm, new_tbl_name = NULL, repair = "unique", qu
     dm_from_def(zoomed = TRUE, validate = FALSE)
 
   dm_wo_outgoing_fks %>%
-    dm_insert_zoomed_outgoing_fks(new_tbl_name_chr, names_list$old_new_names[old_tbl_name], col_tracker_zoomed(dm)) %>%
+    dm_insert_zoomed_outgoing_fks(
+      new_tbl_name_chr,
+      names_list$old_new_names[old_tbl_name],
+      col_tracker_zoomed(dm)
+    ) %>%
     dm_clean_zoomed()
 }
 
 dm_select_tbl_zoomed_impl <- function(dm, selected) {
-  if (anyDuplicated(names(selected))) abort_need_unique_names(names(selected[duplicated(names(selected))]))
+  if (anyDuplicated(names(selected))) {
+    abort_need_unique_names(names(selected[duplicated(names(selected))]))
+  }
 
   def <-
     dm_get_def(dm) %>%
@@ -627,8 +694,14 @@ dm_select_tbl_zoomed_impl <- function(dm, selected) {
   dm_from_def(def, zoomed = TRUE)
 }
 
-dm_add_tbl_zoomed_impl <- function(dm, tbls, table_name, filters = list_of(new_filter()),
-                                   pks = list_of(new_pk()), fks = list_of(new_fk())) {
+dm_add_tbl_zoomed_impl <- function(
+  dm,
+  tbls,
+  table_name,
+  filters = list_of(new_filter()),
+  pks = list_of(new_pk()),
+  fks = list_of(new_fk())
+) {
   def <- dm_get_def(dm)
 
   def_0 <- def[rep_along(table_name, NA_integer_), ]
@@ -646,7 +719,7 @@ dm_add_tbl_zoomed_impl <- function(dm, tbls, table_name, filters = list_of(new_f
 #' @keywords internal
 #' @export
 cdm_update_zoomed_tbl <- function(dm) {
-  deprecate_soft("0.1.0", "dm::cdm_update_zoomed_tbl()", "dm::dm_update_zoomed()")
+  deprecate_warn("0.1.0", "dm::cdm_update_zoomed_tbl()", "dm::dm_update_zoomed()")
   dm_update_zoomed(dm = dm)
 }
 
@@ -654,7 +727,7 @@ cdm_update_zoomed_tbl <- function(dm) {
 #' @keywords internal
 #' @export
 cdm_zoom_out <- function(dm) {
-  deprecate_soft("0.1.0", "dm::cdm_zoom_out()", "dm::dm_discard_zoomed()")
+  deprecate_warn("0.1.0", "dm::cdm_zoom_out()", "dm::dm_discard_zoomed()")
   dm_discard_zoomed(dm = dm)
 }
 
@@ -662,7 +735,7 @@ cdm_zoom_out <- function(dm) {
 #' @keywords internal
 #' @export
 dm_rm_tbl <- function(dm, ...) {
-  deprecate_soft("1.0.0", "dm::dm_rm_tbl()", "dm::dm_select_tbl()")
+  deprecate_warn("1.0.0", "dm::dm_rm_tbl()", "dm::dm_select_tbl()")
   # since deprecated cdm_rm_tbl() was calling dm_rm_tbl() we need dm_rm_tbl_impl
   dm_rm_tbl_impl(dm, ...)
 }
@@ -676,11 +749,10 @@ dm_rm_tbl_impl <- function(dm, ...) {
 }
 
 abort_rm_fk_col_missing <- function() {
-  abort(error_txt_rm_fk_col_missing(), class = dm_error_full("rm_fk_col_missing"))
-}
-
-error_txt_rm_fk_col_missing <- function() {
-  "Parameter `columns` has to be set. Pass `NULL` for removing all references."
+  cli::cli_abort(
+    "Parameter {.arg columns} has to be set. Pass {.val {I('NULL')}} for removing all references.",
+    class = dm_error_full("rm_fk_col_missing")
+  )
 }
 
 #' @description
@@ -690,7 +762,10 @@ error_txt_rm_fk_col_missing <- function() {
 #' @keywords internal
 #' @export
 dm_add_tbl <- function(dm, ..., repair = "unique", quiet = FALSE) {
-  deprecate_soft("1.0.0", "dm_add_tbl()", "dm()",
+  deprecate_warn(
+    "1.0.0",
+    "dm_add_tbl()",
+    "dm()",
     details = 'Use `.name_repair = "unique"` if necessary.'
   )
 
@@ -717,7 +792,7 @@ dm_add_tbl <- function(dm, ..., repair = "unique", quiet = FALSE) {
 #' @keywords internal
 #' @export
 dm_bind <- function(..., repair = "check_unique", quiet = FALSE) {
-  deprecate_soft("1.0.0", "dm_bind()", "dm()")
+  deprecate_warn("1.0.0", "dm_bind()", "dm()")
 
   dms <- list2(...)
 
@@ -727,24 +802,38 @@ dm_bind <- function(..., repair = "check_unique", quiet = FALSE) {
 
 #' @description
 #' `dm_squash_to_tbl()`  is deprecated as of dm 1.0.0, because the same functionality
-#' is offered by [dm_flatten_to_tbl()] with `recursive = TRUE`.
+#' is offered by [dm_flatten_to_tbl()] with `.recursive = TRUE`.
 #'
 #' @rdname deprecated
 #' @keywords internal
 #'
 #' @export
 dm_squash_to_tbl <- function(dm, start, ..., join = left_join) {
-  deprecate_soft("1.0.0", "dm_squash_to_tbl()", details = "Please use `recursive = TRUE` in `dm_flatten_to_tbl()` instead.")
+  deprecate_warn(
+    "1.0.0",
+    "dm_squash_to_tbl()",
+    details = "Please use `.recursive = TRUE` in `dm_flatten_to_tbl()` instead."
+  )
 
   check_not_zoomed(dm)
   join_name <- as_label(enexpr(join))
-  if (!(join_name %in% c("left_join", "full_join", "inner_join"))) abort_squash_limited()
+  if (!(join_name %in% c("left_join", "full_join", "inner_join"))) {
+    abort_squash_limited()
+  }
   start <- dm_tbl_name(dm, {{ start }})
 
   vars <- setdiff(src_tbls_impl(dm), start)
   list_of_pts <- eval_select_table(quo(c(...)), vars)
 
-  dm_flatten_to_tbl_impl(dm, start, list_of_pts, join = join, join_name = join_name, squash = TRUE, .position = "prefix")
+  dm_flatten_to_tbl_impl(
+    dm,
+    start,
+    list_of_pts,
+    join = join,
+    join_name = join_name,
+    squash = TRUE,
+    .position = "prefix"
+  )
 }
 
 #' @description
@@ -756,7 +845,7 @@ dm_squash_to_tbl <- function(dm, start, ..., join = left_join) {
 #' @keywords internal
 #' @export
 rows_truncate <- function(x, ..., in_place = FALSE) {
-  deprecate_soft("1.0.0", "rows_truncate()")
+  deprecate_warn("1.0.0", "rows_truncate()")
 
   check_dots_used(action = warn)
   UseMethod("rows_truncate", x)
@@ -773,8 +862,7 @@ rows_truncate.data.frame <- function(x, ..., in_place = NULL) {
 }
 
 #' @export
-rows_truncate.tbl_sql <- function(x, ...,
-                                  in_place = NULL) {
+rows_truncate.tbl_sql <- function(x, ..., in_place = NULL) {
   name <- target_table_name(x, in_place)
 
   if (!is_null(name)) {
@@ -793,7 +881,7 @@ rows_truncate.tbl_sql <- function(x, ...,
 #'
 #' @export
 sql_rows_truncate <- function(x, ...) {
-  deprecate_soft("1.0.0", "sql_rows_truncate()")
+  deprecate_warn("1.0.0", "sql_rows_truncate()")
 
   check_dots_used()
   UseMethod("sql_rows_truncate")
@@ -824,15 +912,21 @@ target_table_name <- function(x, in_place) {
 
   # Abort if requested but can't write
   if (is_null(name) && is_true(in_place)) {
-    abort("Can't determine name for target table. Set `in_place = FALSE` to return a lazy table.")
+    cli::cli_abort(
+      "Can't determine name for target table. Set {.code in_place = FALSE} to return a lazy table."
+    )
   }
 
   # Verbose by default
   if (is_null(in_place)) {
     if (is_null(name)) {
-      inform("Result is returned as lazy table, because `x` does not correspond to a table that can be updated. Use `in_place = FALSE` to mute this message.")
+      inform(
+        "Result is returned as lazy table, because `x` does not correspond to a table that can be updated. Use `in_place = FALSE` to mute this message."
+      )
     } else {
-      inform("Result is returned as lazy table. Use `in_place = FALSE` to mute this message, or `in_place = TRUE` to write to the underlying table.")
+      inform(
+        "Result is returned as lazy table. Use `in_place = FALSE` to mute this message, or `in_place = TRUE` to write to the underlying table."
+      )
     }
   }
 
@@ -845,7 +939,7 @@ target_table_name <- function(x, in_place) {
 #'
 #' @export
 dm_rows_truncate <- function(x, y, ..., in_place = NULL, progress = NA) {
-  deprecate_soft("1.0.0", "dm_rows_truncate()")
+  deprecate_warn("1.0.0", "dm_rows_truncate()")
   check_dots_empty()
 
   dm_rows(x, y, "truncate", top_down = FALSE, in_place, require_keys = FALSE, progress = progress)
