@@ -1,16 +1,41 @@
 expect_identical_graph <- function(g1, g2) {
-  expect_true(igraph::identical_graphs(g1, g2))
+  if (inherits(g1, "dm_igraph") && inherits(g2, "dm_igraph")) {
+    expect_true(igraph::identical_graphs(g1$igraph, g2$igraph))
+  } else {
+    expect_setequal(g1$vnames, g2$vnames)
+    edges1 <- sort(paste(g1$vnames[g1$from], g1$vnames[g1$to]))
+    edges2 <- sort(paste(g2$vnames[g2$from], g2$vnames[g2$to]))
+    expect_equal(edges1, edges2)
+  }
 }
 
-expect_equivalent_dm <- function(object, expected, sort = FALSE, ..., sort_tables = sort, sort_columns = sort, sort_keys = sort, ignore_on_delete = FALSE, ignore_autoincrement = FALSE) {
+expect_equivalent_dm <- function(
+  object,
+  expected,
+  sort = FALSE,
+  ...,
+  sort_tables = sort,
+  sort_columns = sort,
+  sort_keys = sort,
+  ignore_on_delete = FALSE,
+  ignore_autoincrement = FALSE
+) {
   tables1 <- dm_get_tables_impl(object) %>% map(collect)
   tables2 <- dm_get_tables_impl(expected) %>% map(collect)
 
-  expect_equivalent_tbl_lists(tables1, tables2, sort_tables = sort_tables, sort_columns = sort_columns)
+  expect_equivalent_tbl_lists(
+    tables1,
+    tables2,
+    sort_tables = sort_tables,
+    sort_columns = sort_columns
+  )
 
   if (sort_keys) {
     if (ignore_autoincrement) {
-      expect_equivalent_tbl(dm_get_all_pks_impl(object) %>% select(-autoincrement), dm_get_all_pks_impl(expected) %>% select(-autoincrement))
+      expect_equivalent_tbl(
+        dm_get_all_pks_impl(object) %>% select(-autoincrement),
+        dm_get_all_pks_impl(expected) %>% select(-autoincrement)
+      )
     } else {
       expect_equivalent_tbl(dm_get_all_pks_impl(object), dm_get_all_pks_impl(expected))
     }
@@ -20,7 +45,10 @@ expect_equivalent_dm <- function(object, expected, sort = FALSE, ..., sort_table
     )
   } else {
     if (ignore_autoincrement) {
-      expect_equivalent_tbl(dm_get_all_pks_impl(object) %>% select(-autoincrement), dm_get_all_pks_impl(expected) %>% select(-autoincrement))
+      expect_equivalent_tbl(
+        dm_get_all_pks_impl(object) %>% select(-autoincrement),
+        dm_get_all_pks_impl(expected) %>% select(-autoincrement)
+      )
     } else {
       expect_equivalent_tbl(dm_get_all_pks_impl(object), dm_get_all_pks_impl(expected))
     }
@@ -74,7 +102,14 @@ harmonize_tbl <- function(tbl, ...) {
 }
 
 # are two tables identical minus the `src`
-expect_equivalent_tbl <- function(tbl_1, tbl_2, ..., .label = NULL, .expected_label = NULL, .sort_columns = FALSE) {
+expect_equivalent_tbl <- function(
+  tbl_1,
+  tbl_2,
+  ...,
+  .label = NULL,
+  .expected_label = NULL,
+  .sort_columns = FALSE
+) {
   if (.sort_columns) {
     tbl_1 <- select(tbl_1, !!!sort(names(tbl_1)))
     tbl_2 <- select(tbl_2, !!!sort(names(tbl_2)))
@@ -85,7 +120,12 @@ expect_equivalent_tbl <- function(tbl_1, tbl_2, ..., .label = NULL, .expected_la
 }
 
 # are two lists of tables identical minus the `src`
-expect_equivalent_tbl_lists <- function(object, expected, sort_tables = FALSE, sort_columns = FALSE) {
+expect_equivalent_tbl_lists <- function(
+  object,
+  expected,
+  sort_tables = FALSE,
+  sort_columns = FALSE
+) {
   expect_equal(length(object), length(expected))
   if (length(object) == length(expected)) {
     if (sort_tables) {
