@@ -3,7 +3,10 @@ test_that("DB helpers work for MSSQL", {
   con_mssql <- my_test_src()$con
   expect_identical(schema_mssql(con_mssql, "schema"), "schema")
   expect_identical(schema_mssql(con_mssql, NULL), "dbo")
-  expect_identical(dbname_mssql(con_mssql, "database_2"), set_names("\"database_2\".", "database_2"))
+  expect_identical(
+    dbname_mssql(con_mssql, "database_2"),
+    set_names("\"database_2\".", "database_2")
+  )
   expect_identical(dbname_mssql(con_mssql, NULL), set_names("", ""))
 
   withr::defer({
@@ -12,7 +15,10 @@ test_that("DB helpers work for MSSQL", {
     try(DBI::dbExecute(con_mssql, "DROP TABLE schema_db_helpers.test_db_helpers_2"))
     try(DBI::dbExecute(con_mssql, "DROP SCHEMA schema_db_helpers"))
     try(DBI::dbExecute(con_mssql, "DROP TABLE [db_helpers_db].[dbo].[test_db_helpers_3]"))
-    try(DBI::dbExecute(con_mssql, "DROP TABLE [db_helpers_db].[schema_db_helpers_2].[test_db_helpers_4]"))
+    try(DBI::dbExecute(
+      con_mssql,
+      "DROP TABLE [db_helpers_db].[schema_db_helpers_2].[test_db_helpers_4]"
+    ))
     # dropping schema is unnecessary
     try(DBI::dbExecute(con_mssql, "DROP DATABASE db_helpers_db"))
   })
@@ -66,40 +72,62 @@ test_that("DB helpers work for MSSQL", {
     DBI::Id(catalog = "db_helpers_db", schema = "dbo", table = "test_db_helpers_3")
   )
   expect_identical(
-    get_src_tbl_names(my_test_src(), dbname = "db_helpers_db", schema = "schema_db_helpers_2")[["test_db_helpers_4"]],
+    get_src_tbl_names(my_test_src(), dbname = "db_helpers_db", schema = "schema_db_helpers_2")[[
+      "test_db_helpers_4"
+    ]],
     DBI::Id(catalog = "db_helpers_db", schema = "schema_db_helpers_2", table = "test_db_helpers_4")
   )
   expect_identical(
-    get_src_tbl_names(my_test_src(), schema = c("dbo", "schema_db_helpers"))[["dbo.test_db_helpers_2"]],
+    get_src_tbl_names(
+      my_test_src(),
+      schema = c("dbo", "schema_db_helpers"),
+      names_pattern = "{.schema}.{.table}"
+    )[["dbo.test_db_helpers_2"]],
     DBI::Id(schema = "dbo", table = "test_db_helpers_2")
   )
   expect_identical(
-    get_src_tbl_names(my_test_src(), schema = c("dbo", "schema_db_helpers"))[["schema_db_helpers.test_db_helpers_2"]],
+    get_src_tbl_names(
+      my_test_src(),
+      schema = c("dbo", "schema_db_helpers"),
+      names_pattern = "{.schema}.{.table}"
+    )[["schema_db_helpers.test_db_helpers_2"]],
     DBI::Id(schema = "schema_db_helpers", table = "test_db_helpers_2")
   )
   expect_warning(
-    out <- get_src_tbl_names(my_test_src(), schema = c("dbo", "schema_db_helpers"), names = "{.table}")["test_db_helpers_2"],
+    out <- get_src_tbl_names(
+      my_test_src(),
+      schema = c("dbo", "schema_db_helpers"),
+      names_pattern = "{.table}"
+    )["test_db_helpers_2"],
     'Local name test_db_helpers_2 will refer to <"dbo"."test_db_helpers_2">, rather than to <"schema_db_helpers"."test_db_helpers_2">',
     fixed = TRUE
   )
   expect_identical(
     out,
-    list(test_db_helpers_2 = DBI::Id(
-      schema = "dbo",
-      table = "test_db_helpers_2"
-    ))
+    list(
+      test_db_helpers_2 = DBI::Id(
+        schema = "dbo",
+        table = "test_db_helpers_2"
+      )
+    )
   )
   expect_warning(
-    out <- get_src_tbl_names(my_test_src(), schema = c("schema_db_helpers", "dbo"), names = "{.table}")["test_db_helpers_2"],
+    out <- get_src_tbl_names(
+      my_test_src(),
+      schema = c("schema_db_helpers", "dbo"),
+      names_pattern = "{.table}"
+    )["test_db_helpers_2"],
     'Local name test_db_helpers_2 will refer to <"schema_db_helpers"."test_db_helpers_2">, rather than to <"dbo"."test_db_helpers_2">',
     fixed = TRUE
   )
   expect_identical(
     out,
-    list(test_db_helpers_2 = DBI::Id(
-      schema = "schema_db_helpers",
-      table = "test_db_helpers_2"
-    ))
+    list(
+      test_db_helpers_2 = DBI::Id(
+        schema = "schema_db_helpers",
+        table = "test_db_helpers_2"
+      )
+    )
   )
 })
 
@@ -145,36 +173,56 @@ test_that("DB helpers work for Postgres", {
     DBI::Id(schema = "schema_db_helpers", table = "test_db_helpers_2")
   )
   expect_identical(
-    get_src_tbl_names(my_test_src(), schema = c("public", "schema_db_helpers"))["public.test_db_helpers_2"][[1]],
+    get_src_tbl_names(
+      my_test_src(),
+      schema = c("public", "schema_db_helpers"),
+      names_pattern = "{.schema}.{.table}"
+    )["public.test_db_helpers_2"][[1]],
     DBI::Id(schema = "public", table = "test_db_helpers_2")
   )
   expect_identical(
-    get_src_tbl_names(my_test_src(), schema = c("public", "schema_db_helpers"))["schema_db_helpers.test_db_helpers_2"][[1]],
+    get_src_tbl_names(
+      my_test_src(),
+      schema = c("public", "schema_db_helpers"),
+      names_pattern = "{.schema}.{.table}"
+    )["schema_db_helpers.test_db_helpers_2"][[1]],
     DBI::Id(schema = "schema_db_helpers", table = "test_db_helpers_2")
   )
   expect_warning(
-    out <- get_src_tbl_names(my_test_src(), schema = c("public", "schema_db_helpers"), names = "{.table}")["test_db_helpers_2"],
+    out <- get_src_tbl_names(
+      my_test_src(),
+      schema = c("public", "schema_db_helpers"),
+      names_pattern = "{.table}"
+    )["test_db_helpers_2"],
     'Local name test_db_helpers_2 will refer to <"public"."test_db_helpers_2">, rather than to <"schema_db_helpers"."test_db_helpers_2">',
     fixed = TRUE
   )
   expect_identical(
     out,
-    list(test_db_helpers_2 = DBI::Id(
-      schema = "public",
-      table = "test_db_helpers_2"
-    ))
+    list(
+      test_db_helpers_2 = DBI::Id(
+        schema = "public",
+        table = "test_db_helpers_2"
+      )
+    )
   )
   expect_warning(
-    out <- get_src_tbl_names(my_test_src(), schema = c("schema_db_helpers", "public"), names = "{.table}")["test_db_helpers_2"],
+    out <- get_src_tbl_names(
+      my_test_src(),
+      schema = c("schema_db_helpers", "public"),
+      names_pattern = "{.table}"
+    )["test_db_helpers_2"],
     'Local name test_db_helpers_2 will refer to <"schema_db_helpers"."test_db_helpers_2">, rather than to <"public"."test_db_helpers_2">',
     fixed = TRUE
   )
   expect_identical(
     out,
-    list(test_db_helpers_2 = DBI::Id(
-      schema = "schema_db_helpers",
-      table = "test_db_helpers_2"
-    ))
+    list(
+      test_db_helpers_2 = DBI::Id(
+        schema = "schema_db_helpers",
+        table = "test_db_helpers_2"
+      )
+    )
   )
 })
 
@@ -198,7 +246,10 @@ test_that("DB helpers work for other DBMS than MSSQL or Postgres", {
   # test for 2 warnings and if the output contains the new table
   expect_dm_warning(
     expect_dm_warning(
-      expect_true("test_db_helpers" %in% names(get_src_tbl_names(my_db_test_src(), schema = "schema", dbname = "dbname"))),
+      expect_true(
+        "test_db_helpers" %in%
+          names(get_src_tbl_names(my_db_test_src(), schema = "schema", dbname = "dbname"))
+      ),
       class = "arg_not"
     ),
     class = "arg_not"
@@ -208,7 +259,9 @@ test_that("DB helpers work for other DBMS than MSSQL or Postgres", {
 
   # test for warning and if the output contains the new table
   expect_dm_warning(
-    expect_true("test_db_helpers" %in% names(get_src_tbl_names(my_db_test_src(), dbname = "dbname"))),
+    expect_true(
+      "test_db_helpers" %in% names(get_src_tbl_names(my_db_test_src(), dbname = "dbname"))
+    ),
     class = "arg_not"
   )
 })
@@ -222,7 +275,6 @@ test_that("find name clashes", {
   # ... we shouldn't get anything
   expect_length(res, 0)
 
-
   # If multiple old names change to the same new name...
   res <- find_name_clashes(
     c("one", "two", "three"),
