@@ -28,11 +28,14 @@ test_that("`dm_set_colors()` works", {
   colset <- c(blue = "flights", green = "airports")
 
   # test splicing
-  expect_snapshot(variant = if (packageVersion("testthat") > "3.1.0") "testthat-new" else "testthat-legacy", {
-    dm_nycflights_small() %>%
-      dm_set_colors(!!!colset) %>%
-      dm_get_colors()
-  })
+  expect_snapshot(
+    variant = if (packageVersion("testthat") > "3.1.0") "testthat-new" else "testthat-legacy",
+    {
+      dm_nycflights_small() %>%
+        dm_set_colors(!!!colset) %>%
+        dm_get_colors()
+    }
+  )
 })
 
 test_that("`dm_set_colors()` errors if old syntax used", {
@@ -63,7 +66,7 @@ test_that("last", {
     color_quos_to_display(
       flights = "blue",
       airlines =
-      ),
+    ),
     class = "last_col_missing"
   )
 })
@@ -160,20 +163,24 @@ test_that("table_description works", {
   expect_snapshot_diagram(
     dm_nycflights_small() %>%
       dm_set_table_description("high in the sky\nflying from NY" = flights) %>%
-      dm_draw(font_size = list(table_description = 6L)),
+      dm_draw(backend_opts = list(font_size = list(table_description = 6L))),
     "table-desc-2-dm.svg"
   )
 
   expect_snapshot_diagram(
     dm_nycflights_small() %>%
       dm_set_table_description("high in the sky\nflying from NY" = flights) %>%
-      dm_draw(font_size = c(table_description = 6L, header = 19L, column = 14L)),
+      dm_draw(
+        backend_opts = list(font_size = c(table_description = 6L, header = 19L, column = 14L))
+      ),
     "table-desc-3-dm.svg"
   )
 
   expect_snapshot_diagram(
     dm_nycflights13(table_description = TRUE) %>%
-      dm_draw(font_size = c(table_description = 6L, header = 19L, column = 14L)),
+      dm_draw(
+        backend_opts = list(font_size = c(table_description = 6L, header = 19L, column = 14L))
+      ),
     "table-desc-4-dm.svg"
   )
 })
@@ -195,3 +202,48 @@ test_that("UK support works", {
     "table-uk-2-dm.svg"
   )
 })
+
+test_that("DiagrammeR-specific options are soft-deprecated", {
+  skip_if_not_installed("DiagrammeR")
+
+  expect_snapshot({
+    dm_nycflights13() |>
+      dm_draw(graph_attrs = "rankdir=LR") |>
+      invisible()
+  })
+
+  expect_snapshot({
+    dm_nycflights13() |>
+      dm_draw(font_size = 14L) |>
+      invisible()
+  })
+})
+
+test_that("unsupported backend_opts fail with clear error", {
+  expect_snapshot(
+    dm_nycflights13() |> dm_draw(backend_opts = list(columnArrows = TRUE)),
+    error = TRUE
+  )
+
+  expect_snapshot(
+    dm_nycflights13() |> dm_draw(backend_opts = list(foo = 1, bar = 2)),
+    error = TRUE
+  )
+})
+
+test_that("column_arrow backend option works", {
+  skip_if_not_installed("DiagrammeR")
+
+  expect_snapshot({
+    dm_nycflights13() |>
+      dm_draw(columnArrows = FALSE) |>
+      invisible()
+  })
+
+  # Directly using column_arrow in backend_opts should work without warning
+  expect_no_warning(
+    dm_nycflights13() |>
+      dm_draw(backend_opts = list(column_arrow = FALSE)) |>
+      invisible()
+  )
+})
