@@ -17,7 +17,11 @@ test_that("`dm_flatten_to_tbl()` does the right things for 'left_join()'", {
 
   expect_snapshot(
     {
-      prepare_dm_for_flatten(dm_for_flatten(), tables = c("fact", "dim_1", "dim_2", "dim_3", "dim_4"), gotta_rename = TRUE) %>%
+      prepare_dm_for_flatten(
+        dm_for_flatten(),
+        tables = c("fact", "dim_1", "dim_2", "dim_3", "dim_4"),
+        gotta_rename = TRUE
+      ) %>%
         dm_get_tables()
       dm_flatten_to_tbl(dm_for_flatten(), fact)
       result_from_flatten_new()
@@ -35,7 +39,10 @@ test_that("`dm_flatten_to_tbl()` does the right things for 'left_join()'", {
 
   # explicitly choose parent tables
   out <- expect_message_obj(dm_flatten_to_tbl(
-    dm_for_flatten(), fact, dim_1, dim_2
+    dm_for_flatten(),
+    fact,
+    dim_1,
+    dim_2
   ))
   expect_equivalent_tbl(
     out,
@@ -49,15 +56,22 @@ test_that("`dm_flatten_to_tbl()` does the right things for 'left_join()'", {
 
   # change order of parent tables
   out <- expect_message_obj(dm_flatten_to_tbl(
-    dm_for_flatten(), fact, dim_2, dim_1
+    dm_for_flatten(),
+    fact,
+    dim_2,
+    dim_1
   ))
   expect_equivalent_tbl(
     out,
     left_join(
-      fact_clean_new(), dim_2_clean_new(),
+      fact_clean_new(),
+      dim_2_clean_new(),
       by = c("dim_2_key" = "dim_2_pk")
     ) %>%
-      left_join(dim_1_clean_new(), by = c("dim_1_key_1" = "dim_1_pk_1", "dim_1_key_2" = "dim_1_pk_2"))
+      left_join(
+        dim_1_clean_new(),
+        by = c("dim_1_key_1" = "dim_1_pk_1", "dim_1_key_2" = "dim_1_pk_2")
+      )
   )
 
   # with grandparent table
@@ -108,13 +122,17 @@ test_that("`dm_flatten_to_tbl()` does the right things for 'full_join()'", {
   skip_if_src("sqlite")
   skip_if_src("maria")
   out <- expect_message_obj(dm_flatten_to_tbl(
-    dm_for_flatten(), fact,
+    dm_for_flatten(),
+    fact,
     .join = full_join
   ))
   expect_equivalent_tbl(
     out,
     fact_clean_new() %>%
-      full_join(dim_1_clean_new(), by = c("dim_1_key_1" = "dim_1_pk_1", "dim_1_key_2" = "dim_1_pk_2")) %>%
+      full_join(
+        dim_1_clean_new(),
+        by = c("dim_1_key_1" = "dim_1_pk_1", "dim_1_key_2" = "dim_1_pk_2")
+      ) %>%
       full_join(dim_2_clean_new(), by = c("dim_2_key" = "dim_2_pk")) %>%
       full_join(dim_3_clean_new(), by = c("dim_3_key" = "dim_3_pk")) %>%
       full_join(dim_4_clean_new(), by = c("dim_4_key" = "dim_4_pk"))
@@ -151,7 +169,10 @@ test_that("`dm_flatten_to_tbl()` does the right things for 'right_join()'", {
       "right_join"
     )),
     fact_clean_new() %>%
-      right_join(dim_1_clean_new(), by = c("dim_1_key_1" = "dim_1_pk_1", "dim_1_key_2" = "dim_1_pk_2")) %>%
+      right_join(
+        dim_1_clean_new(),
+        by = c("dim_1_key_1" = "dim_1_pk_1", "dim_1_key_2" = "dim_1_pk_2")
+      ) %>%
       right_join(dim_2_clean_new(), by = c("dim_2_key" = "dim_2_pk")) %>%
       right_join(dim_3_clean_new(), by = c("dim_3_key" = "dim_3_pk")) %>%
       right_join(dim_4_clean_new(), by = c("dim_4_key" = "dim_4_pk"))
@@ -159,7 +180,10 @@ test_that("`dm_flatten_to_tbl()` does the right things for 'right_join()'", {
 
   # change order of parent tables
   out <- expect_message_obj(dm_flatten_to_tbl(
-    dm_for_flatten(), fact, dim_2, dim_1,
+    dm_for_flatten(),
+    fact,
+    dim_2,
+    dim_1,
     .join = right_join
   ))
   expect_equivalent_tbl(
@@ -169,7 +193,10 @@ test_that("`dm_flatten_to_tbl()` does the right things for 'right_join()'", {
       dim_2_clean_new(),
       by = c("dim_2_key" = "dim_2_pk")
     ) %>%
-      right_join(dim_1_clean_new(), by = c("dim_1_key_1" = "dim_1_pk_1", "dim_1_key_2" = "dim_1_pk_2"))
+      right_join(
+        dim_1_clean_new(),
+        by = c("dim_1_key_1" = "dim_1_pk_1", "dim_1_key_2" = "dim_1_pk_2")
+      )
   )
 })
 
@@ -203,7 +230,6 @@ test_that("`dm_flatten_to_tbl(.recursive = TRUE)` does the right things", {
     12L
   )
 
-
   # semi_join:
   expect_dm_error(
     dm_flatten_to_tbl(dm_more_complex(), tf_5, tf_4, tf_3, .join = semi_join, .recursive = TRUE),
@@ -319,7 +345,6 @@ test_that("tests with 'bad_dm' work", {
   # duckdb doesn't work before R 4.0
   skip_if(getRversion() < "4.0")
 
-
   # flatten bad_dm() (no referential integrity)
   if (is_db(my_test_src()) || utils::packageVersion("dplyr") >= "1.1.0.9000") {
     expect_equivalent_tbl(
@@ -330,7 +355,6 @@ test_that("tests with 'bad_dm' work", {
     )
   }
 
-
   skip_if_src("maria")
 
   # filtered `dm`
@@ -341,7 +365,6 @@ test_that("tests with 'bad_dm' work", {
     bad_filtered_dm %>% dm_flatten_to_tbl(tbl_1)
   )
 
-
   # filtered `dm`
   expect_equivalent_tbl(
     dm_flatten_to_tbl(bad_filtered_dm, tbl_1, .join = semi_join),
@@ -402,7 +425,6 @@ test_that("tests with 'bad_dm' work (3)", {
     )
   }
 
-
   # flatten bad_dm() (no referential integrity); different order
   if (is_db(my_test_src()) || utils::packageVersion("dplyr") >= "1.1.0.9000") {
     expect_equivalent_tbl(
