@@ -46,7 +46,6 @@ test_that("schema handling on MSSQL and Postgres works", {
   expect_false("test_schema_1" %in% sql_schema_table_list(con_db)$table_name)
   expect_false("test_schema_1" %in% sql_schema_table_list(src_db)$table_name)
 
-
   DBI::dbWriteTable(
     con_db,
     DBI::Id(table = "test_schema_1"),
@@ -192,7 +191,11 @@ test_that("schema handling on MSSQL works for different DBs", {
     sql_schema_table_list_mssql(con_db, schema = "test_schema", dbname = "test_db_for_schema_dm"),
     tibble(
       table_name = "test_1",
-      remote_name = list(DBI::Id(catalog = "test_db_for_schema_dm", schema = "test_schema", table = "test_1"))
+      remote_name = list(DBI::Id(
+        catalog = "test_db_for_schema_dm",
+        schema = "test_schema",
+        table = "test_1"
+      ))
     )
   )
 })
