@@ -86,8 +86,10 @@ test_that("dm_select() removes fks if not in selection", {
 
 test_that("output for compound keys", {
   expect_snapshot({
-    dm_select(dm_for_flatten(), fact, dim_1_key_1, dim_1_key_2) %>% dm_paste(options = c("select", "keys"))
-    dm_select(dm_for_flatten(), dim_1, dim_1_pk_1, dim_1_pk_2) %>% dm_paste(options = c("select", "keys"))
+    dm_select(dm_for_flatten(), fact, dim_1_key_1, dim_1_key_2) %>%
+      dm_paste(options = c("select", "keys"))
+    dm_select(dm_for_flatten(), dim_1, dim_1_pk_1, dim_1_pk_2) %>%
+      dm_paste(options = c("select", "keys"))
     dm_select(dm_for_flatten(), fact, -dim_1_key_1) %>% dm_paste(options = c("select", "keys"))
     dm_select(dm_for_flatten(), dim_1, -dim_1_pk_1) %>% dm_paste(options = c("select", "keys"))
   })
